@@ -17,19 +17,16 @@
 import click
 
 from polyaxon.connections.kinds import V1ConnectionKind
-from polyaxon.logger import clean_outputs
 from polyaxon.schemas.types import V1ConnectionType
 from polyaxon.utils.formatting import Printer
 
 
 @click.group()
-@clean_outputs
 def initializer():
     pass
 
 
 @initializer.command()
-@clean_outputs
 def auth():
     """Create auth context."""
     from polyaxon.init.auth import create_auth_context
@@ -40,26 +37,29 @@ def auth():
 @initializer.command()
 @click.option("--url", help="The git url to pull.")
 @click.option("--revision", help="The revision(commint/branch/treeish) to pull.")
-@click.option("--repo_path", "--repo-path", help="The path to where to pull the repos.")
+@click.option("--repo-path", help="The path to where to pull the repos.")
 @click.option("--connection", help="The connection used for pulling this repo.")
-@clean_outputs
-def git(url, repo_path, revision, connection):
+@click.option("--flags", help="Additional flags for pulling this repo.")
+def git(url, repo_path, revision, connection, flags):
     """Create auth context."""
     from polyaxon.init.git import create_code_repo
 
     create_code_repo(
-        repo_path=repo_path, url=url, revision=revision, connection=connection
+        repo_path=repo_path,
+        url=url,
+        revision=revision,
+        connection=connection,
+        flags=flags,
     )
 
-    Printer.print_success("Git Repo is now initialized, path: `{}`".format(repo_path))
+    Printer.print_success("Git Repo is initialized, path: `{}`".format(repo_path))
 
 
 @initializer.command()
-@click.option("--connection_name", "--connection-name", help="The connection name.")
-@click.option("--path_from", "--path-from", help="The s3 path to download data from.")
-@click.option("--path_to", "--path-to", help="The local path to store the data.")
+@click.option("--connection-name", help="The connection name.")
+@click.option("--path-from", help="The s3 path to download data from.")
+@click.option("--path-to", help="The local path to store the data.")
 @click.option(
-    "--is_file",
     "--is-file",
     is_flag=True,
     default=False,
@@ -68,7 +68,6 @@ def git(url, repo_path, revision, connection):
 @click.option(
     "--workers", type=int, default=50, help="Number of worker threads to use."
 )
-@clean_outputs
 def s3(connection_name, path_from, path_to, is_file, workers):
     """Create s3 path context."""
     from polyaxon.stores.manager import download_file_or_dir
@@ -83,15 +82,14 @@ def s3(connection_name, path_from, path_to, is_file, workers):
         is_file=is_file,
     )
 
-    Printer.print_success("S3 path is now initialized, path: `{}`".format(path_to))
+    Printer.print_success("S3 path is initialized, path: `{}`".format(path_to))
 
 
 @initializer.command()
-@click.option("--connection_name", "--connection-name", help="The connection name.")
-@click.option("--path_from", "--path-from", help="The gcs path to download data from.")
-@click.option("--path_to", "--path-to", help="The local path to store the data.")
+@click.option("--connection-name", help="The connection name.")
+@click.option("--path-from", help="The gcs path to download data from.")
+@click.option("--path-to", help="The local path to store the data.")
 @click.option(
-    "--is_file",
     "--is-file",
     is_flag=True,
     default=False,
@@ -100,7 +98,6 @@ def s3(connection_name, path_from, path_to, is_file, workers):
 @click.option(
     "--workers", type=int, default=50, help="Number of worker threads to use."
 )
-@clean_outputs
 def gcs(connection_name, path_from, path_to, is_file, workers):
     """Create gcs path context."""
     from polyaxon.stores.manager import download_file_or_dir
@@ -115,15 +112,14 @@ def gcs(connection_name, path_from, path_to, is_file, workers):
         is_file=is_file,
     )
 
-    Printer.print_success("GCS path is now initialized, path: `{}`".format(path_to))
+    Printer.print_success("GCS path is initialized, path: `{}`".format(path_to))
 
 
 @initializer.command()
-@click.option("--connection_name", "--connection-name", help="The connection name.")
-@click.option("--path_from", "--path-from", help="The wasb path to download data from.")
-@click.option("--path_to", "--path-to", help="The local path to store the data.")
+@click.option("--connection-name", help="The connection name.")
+@click.option("--path-from", help="The wasb path to download data from.")
+@click.option("--path-to", help="The local path to store the data.")
 @click.option(
-    "--is_file",
     "--is-file",
     is_flag=True,
     default=False,
@@ -132,7 +128,6 @@ def gcs(connection_name, path_from, path_to, is_file, workers):
 @click.option(
     "--workers", type=int, default=50, help="Number of worker threads to use."
 )
-@clean_outputs
 def wasb(connection_name, path_from, path_to, is_file, workers):
     """Create wasb path context."""
     from polyaxon.stores.manager import download_file_or_dir
@@ -147,4 +142,4 @@ def wasb(connection_name, path_from, path_to, is_file, workers):
         is_file=is_file,
     )
 
-    Printer.print_success("WASB path is now initialized, path: `{}`".format(path_to))
+    Printer.print_success("WASB path is initialized, path: `{}`".format(path_to))
