@@ -19,21 +19,23 @@ import sys
 import time
 
 from collections.abc import Mapping
-from typing import Dict, List, Sequence, Union
+from typing import Dict, List, Optional, Sequence, Tuple, Union
 
 import click
 import polyaxon_sdk
 
+from polyaxon_sdk import V1Run
 from polyaxon_sdk.rest import ApiException
 from urllib3.exceptions import HTTPError
 
 from polyaxon import settings
 from polyaxon.cli.errors import handle_cli_error
-from polyaxon.client import PolyaxonClient
+from polyaxon.client.client import PolyaxonClient
 from polyaxon.client.decorators import check_no_op, check_offline
 from polyaxon.containers.contexts import CONTEXT_MOUNT_ARTIFACTS
 from polyaxon.env_vars.getters import (
-    get_project_full_name,
+    get_entity_full_name,
+    get_project_error_message,
     get_project_or_local,
     get_run_info,
     get_run_or_local,
@@ -106,7 +108,7 @@ class RunClient:
 
         try:
             owner, project = get_project_or_local(
-                get_project_full_name(owner=owner, project=project)
+                get_entity_full_name(owner=owner, entity=project)
             )
         except PolyaxonClientException:
             pass
@@ -116,10 +118,14 @@ class RunClient:
                 owner, project, _run_uuid = get_run_info()
                 run_uuid = run_uuid or _run_uuid
             else:
-                raise PolyaxonClientException("Please provide a valid project.")
+                raise PolyaxonClientException(
+                    "Please provide a valid project, "
+                    "or make sure this operation is managed by Polyaxon."
+                )
 
-        if not owner or not project:
-            raise PolyaxonClientException("Please provide a valid project with owner.")
+        error_message = get_project_error_message(owner, project)
+        if error_message:
+            raise PolyaxonClientException(error_message)
 
         self.client = client
         if not (self.client or settings.CLIENT_CONFIG.is_offline):
@@ -132,11 +138,11 @@ class RunClient:
         self._namespace = None
 
     @property
-    def status(self):
+    def status(self) -> str:
         return self._run_data.status
 
     @property
-    def namespace(self):
+    def namespace(self) -> str:
         if self._namespace:
             return self._namespace
         if (
@@ -144,21 +150,21 @@ class RunClient:
             and self.run_data.settings
             and self.run_data.settings.namespace
         ):
-            self._namespace = self.run_data.settings
+            self._namespace = self.run_data.settings.namespace
         else:
             self._namespace = self.get_namespace()
         return self._namespace
 
     @property
-    def owner(self):
+    def owner(self) -> str:
         return self._owner
 
     @property
-    def project(self):
+    def project(self) -> str:
         return self._project
 
     @property
-    def run_uuid(self):
+    def run_uuid(self) -> str:
         return self._run_uuid
 
     @property
@@ -166,7 +172,7 @@ class RunClient:
         return self._run_data
 
     @check_no_op
-    def get_inputs(self):
+    def get_inputs(self) -> Dict:
         """Gets the run's inputs.
         Returns:
             dict, all the run inputs/params.
@@ -174,7 +180,7 @@ class RunClient:
         return self._run_data.inputs
 
     @check_no_op
-    def get_outputs(self):
+    def get_outputs(self) -> Dict:
         """Gets the run's outputs.
         Returns:
              dict, all the run outputs/metrics.
@@ -189,7 +195,9 @@ class RunClient:
             self.owner, self.project, self.run_uuid
         )
 
-    def _update(self, data: Union[Dict, polyaxon_sdk.V1Run], async_req: bool = True):
+    def _update(
+        self, data: Union[Dict, polyaxon_sdk.V1Run], async_req: bool = True
+    ) -> V1Run:
         response = self.client.runs_v1.patch_run(
             owner=self.owner,
             project=self.project,
@@ -203,7 +211,9 @@ class RunClient:
 
     @check_no_op
     @check_offline
-    def update(self, data: Union[Dict, polyaxon_sdk.V1Run], async_req: bool = False):
+    def update(
+        self, data: Union[Dict, polyaxon_sdk.V1Run], async_req: bool = False
+    ) -> V1Run:
         """Updates a run based on the data passed.
 
         [Run API](/docs/api/#operation/PatchRun)
@@ -221,9 +231,12 @@ class RunClient:
     @check_offline
     def _create(
         self, data: Union[Dict, polyaxon_sdk.V1OperationBody], async_req: bool = False
-    ):
+    ) -> V1Run:
         response = self.client.runs_v1.create_run(
-            owner=self.owner, project=self.project, body=data, async_req=async_req,
+            owner=self.owner,
+            project=self.project,
+            body=data,
+            async_req=async_req,
         )
         if not async_req:
             self._run_data = response
@@ -241,7 +254,10 @@ class RunClient:
         description: str = None,
         tags: Union[str, Sequence[str]] = None,
         content: Union[str, Dict, V1Operation] = None,
-    ):
+        is_managed: bool = True,
+        is_approved: Optional[bool] = None,
+        meta_info: Optional[Dict] = None,
+    ) -> V1Run:
         """Creates a new run based on the data passed.
 
         N.B. Create methods are only useful if you want to create a run programmatically,
@@ -264,11 +280,13 @@ class RunClient:
             tags: str or List[str], optional, list of tags,
                 it will override the tags in the operation if provided.
             content: str or Dict or V1Operation, optional.
+            is_managed: bool, flag to create a managed run.
+            is_approved: bool, flag to specify if the run requires human validation.
+            meta_info: dict, meta info to create the run with.
 
         Returns:
             V1Run, run instance from the response.
         """
-        is_managed = True
         if not content:
             is_managed = False
         elif not isinstance(content, (str, Mapping, V1Operation)):
@@ -287,6 +305,8 @@ class RunClient:
             tags=tags,
             content=content,
             is_managed=is_managed,
+            is_approved=is_approved,
+            meta_info=meta_info,
         )
         self._create(data=data, async_req=False)
         self._post_create()
@@ -301,10 +321,11 @@ class RunClient:
         description: str = None,
         tags: Union[str, Sequence[str]] = None,
         params: Dict = None,
-        profile: str = None,
+        presets: List[str] = None,
         queue: str = None,
-        nocache: bool = True,
-    ):
+        nocache: bool = None,
+        cache: bool = None,
+    ) -> V1Run:
         """Creates a new run based on a polyaxonfile.
 
         N.B. Create methods are only useful if you want to create a run programmatically,
@@ -325,14 +346,18 @@ class RunClient:
                 it will override the tags in the operation if provided.
             params: dict, optional, a dictionary of parameters that will be
                 used to resolve the component's inputs/outputs.
-            profile: str, optional, the name of the
-                [run profile](/docs/core/introduction/concepts/#run-profile).
+            presets: List[str], optional, the name of the
+                [presets](/docs/core/introduction/concepts/#preset).
             queue: str, optional, the name of the
                 [queue](/docs/core/scheduling-strategies/queue-routing/) to assign the run to.
-            nocache: bool, optional, to disable
+            nocache: bool, optional, simple flag to disable
                 [cache check](/docs/automation/helpers/cache/).
                 If passed and the Polyaxonfile has cache section,
                 it will be patched with `disabled: true`.
+            cache: bool, optional, simple flag to enable
+                [cache check](/docs/automation/helpers/cache/).
+                If passed and the Polyaxonfile has cache section,
+                it will be patched with `disabled: false`.
 
         Returns:
             V1Run, run instance from the response.
@@ -340,10 +365,11 @@ class RunClient:
         op_spec = check_polyaxonfile(
             polyaxonfile=polyaxonfile,
             params=params,
-            profile=profile,
+            presets=presets,
             queue=queue,
             nocache=nocache,
-            log=False,
+            cache=cache,
+            verbose=False,
         )
         return self.create(
             name=name, description=description, tags=tags, content=op_spec
@@ -358,10 +384,11 @@ class RunClient:
         description: str = None,
         tags: Union[str, Sequence[str]] = None,
         params: Dict = None,
-        profile: str = None,
+        presets: List[str] = None,
         queue: str = None,
-        nocache: bool = True,
-    ):
+        nocache: bool = None,
+        cache: bool = None,
+    ) -> V1Run:
         """Creates a new run from a url containing a Polyaxonfile specification.
 
         N.B. Create methods are only useful if you want to create a run programmatically,
@@ -381,14 +408,18 @@ class RunClient:
                 it will override the tags in the operation if provided.
             params: dict, optional, a dictionary of parameters that will be
                 used to resolve the component's inputs/outputs.
-            profile: str, optional, the name of the
-                [run profile](/docs/core/introduction/concepts/#run-profile).
+            presets: List[str], optional, the name of the
+                [presets](/docs/core/introduction/concepts/#preset).
             queue: str, optional, the name of the
                 [queue](/docs/core/scheduling-strategies/queue-routing/) to assign the run to.
-            nocache: bool, optional, to disable
+            nocache: bool, optional, simple flag to disable
                 [cache check](/docs/automation/helpers/cache/).
                 If passed and the Polyaxonfile has cache section,
                 it will be patched with `disabled: true`.
+            cache: bool, optional, simple flag to enable
+                [cache check](/docs/automation/helpers/cache/).
+                If passed and the Polyaxonfile has cache section,
+                it will be patched with `disabled: false`.
 
         Returns:
             V1Run, run instance from the response.
@@ -396,10 +427,11 @@ class RunClient:
         op_spec = check_polyaxonfile(
             url=url,
             params=params,
-            profile=profile,
+            presets=presets,
             queue=queue,
             nocache=nocache,
-            log=False,
+            cache=cache,
+            verbose=False,
         )
         return self.create(
             name=name, description=description, tags=tags, content=op_spec
@@ -414,10 +446,11 @@ class RunClient:
         description: str = None,
         tags: Union[str, Sequence[str]] = None,
         params: Dict = None,
-        profile: str = None,
+        presets: str = None,
         queue: str = None,
-        nocache: bool = True,
-    ):
+        nocache: bool = None,
+        cache: bool = None,
+    ) -> V1Run:
         """Creates a new run from the hub based on the component name.
 
         N.B. Create methods are only useful if you want to create a run programmatically,
@@ -436,14 +469,18 @@ class RunClient:
                 it will override the tags in the component if provided.
             params: dict, optional, a dictionary of parameters that will be
                 used to resolve the component's inputs/outputs.
-            profile: str, optional, the name of the
-                [run profile](/docs/core/introduction/concepts/#run-profile).
+            presets: List[str], optional, the name of the
+                [presets](/docs/core/introduction/concepts/#preset).
             queue: str, optional, the name of the
                 [queue](/docs/core/scheduling-strategies/queue-routing/) to assign the run to.
-            nocache: bool, optional, to disable
+            nocache: bool, optional, simple flag to disable
                 [cache check](/docs/automation/helpers/cache/).
                 If passed and the Polyaxonfile has cache section,
                 it will be patched with `disabled: true`.
+            cache: bool, optional, simple flag to enable
+                [cache check](/docs/automation/helpers/cache/).
+                If passed and the Polyaxonfile has cache section,
+                it will be patched with `disabled: false`.
 
         Returns:
             V1Run, run instance from the response.
@@ -451,10 +488,11 @@ class RunClient:
         op_spec = check_polyaxonfile(
             hub=component,
             params=params,
-            profile=profile,
+            presets=presets,
             queue=queue,
             nocache=nocache,
-            log=False,
+            cache=cache,
+            verbose=False,
         )
         return self.create(
             name=name, description=description, tags=tags, content=op_spec
@@ -497,7 +535,9 @@ class RunClient:
 
     @check_no_op
     @check_offline
-    def get_statuses(self, last_status: str = None):
+    def get_statuses(
+        self, last_status: str = None
+    ) -> Tuple[str, List[V1StatusCondition]]:
         """Gets the run's statuses.
 
         [Run API](/docs/api/#operation/GetRunStatus)
@@ -555,7 +595,7 @@ class RunClient:
 
         Otherwise, it will wait until the user interrupts the function or reaches a final status.
 
-        N.B. if you want to watch statuses and and receive the status/conditions,
+        N.B. if you want to watch the statuses and and receive the status/conditions,
         please use `watch_statuses` instead which yields the results.
         """
         for status, conditions in self._wait_for_condition(statuses):
@@ -571,9 +611,10 @@ class RunClient:
         If statuses is passed the watch will wait for a condition:
          * last status is one of the statuses passed.
 
-        Otherwise, it will watch until the user interrupts it or reaches a final status.
+        Otherwise, it will watch until the user interrupts it or
+        when the run reaches a final status.
 
-        N.B. if you just wait for a status condition without expecting a yield,
+        N.B. if you just want to wait for a status condition without expecting a yield,
         please use `wait_for_condition` instead
 
         Yields:
@@ -586,7 +627,7 @@ class RunClient:
 
     @check_no_op
     @check_offline
-    def get_logs(self, last_file=None, last_time=None):
+    def get_logs(self, last_file=None, last_time=None) -> "V1Logs":
         """Gets the run's logs.
 
         This method return up-to 2000 line logs per request.
@@ -696,27 +737,31 @@ class RunClient:
 
     @check_no_op
     @check_offline
-    def download_artifact(self, path: str, force: bool = False):
-        """Downloads run artifact.
+    def download_artifact(self, path: str, force: bool = False, path_to: str = None):
+        """Downloads a single run artifact.
 
         Args:
             path: str, the relative path of the artifact to return.
+            path_to: str, optional, path to download to.
             force: bool, force reload the artifact.
 
         Returns:
             str
         """
-        url = "{host}/streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/artifact".format(
-            host=clean_host(self.client.config.host),
+        url = PolyaxonStore.URL.format(
             namespace=self.namespace,
             owner=self.owner,
             project=self.project,
             uuid=self.run_uuid,
+            subpath="artifact",
         )
+        url = "{host}/{url}".format(host=clean_host(self.client.config.host), url=url)
         if force:
             url = "{}?force=true".format(url)
 
-        return PolyaxonStore(client=self).download_file(url=url, path=path, force=force)
+        return PolyaxonStore(client=self).download_file(
+            url=url, path=path, path_to=path_to
+        )
 
     @check_no_op
     @check_offline
@@ -728,7 +773,7 @@ class RunClient:
         delete_tar: bool = True,
         extract_path: str = None,
     ):
-        """Downloads a list of run artifacts.
+        """Downloads a subpath containing multiple run artifacts.
 
         Args:
             path: str, the relative path of the artifact to return.
@@ -740,23 +785,99 @@ class RunClient:
         Returns:
             str.
         """
-        url = "{host}/streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/artifacts".format(
-            host=clean_host(self.client.config.host),
+        url = PolyaxonStore.URL.format(
             namespace=self.namespace,
             owner=self.owner,
             project=self.project,
             uuid=self.run_uuid,
+            subpath="artifacts",
         )
+        url = "{host}/{url}".format(host=clean_host(self.client.config.host), url=url)
 
         return PolyaxonStore(client=self).download_file(
             url=url,
             path=path,
             untar=untar,
             path_to=path_to,
-            delete_tar=delete_tar,
+            delete_tar=delete_tar and untar,
             extract_path=extract_path,
         )
 
+    @check_no_op
+    @check_offline
+    def upload_artifact(
+        self,
+        filepath: str,
+        path: str = None,
+        untar: bool = False,
+        overwrite: bool = True,
+    ):
+        """Uploads a single artifact to the run's artifacts store path.
+
+        Args:
+            filepath: str, the filepath to upload.
+            path: str, optional, path to upload to, otherwise it will be on the run's root path.
+            untar: bool, optional, if the file uploaded is tar.gz and it should be decompressed on the artifacts store.
+            overwrite: bool, optional, if the file uploaded should overwrite any previous content.
+
+        Returns:
+            str
+        """
+        url = PolyaxonStore.URL.format(
+            namespace=self.namespace,
+            owner=self.owner,
+            project=self.project,
+            uuid=self.run_uuid,
+            subpath="artifact",
+        )
+        url = "{host}/{url}".format(host=clean_host(self.client.config.host), url=url)
+
+        return PolyaxonStore(client=self).upload_file(
+            url=url,
+            filepath=filepath,
+            path=path,
+            untar=untar,
+            overwrite=overwrite,
+        )
+
+    @check_no_op
+    @check_offline
+    def upload_artifacts(
+        self,
+        files: List[str],
+        path: str = "",
+        overwrite: bool = True,
+        relative_to: str = None,
+    ):
+        """Uploads a multiple artifacts to the run's artifacts store path.
+
+        Args:
+            files: List[str], list of files to upload.
+            path: str, the relative path of the artifact to return.
+            overwrite: bool, optional, if the file uploaded should overwrite any previous content.
+            relative_to: str, optional, if the path uploaded is not the current dir,
+                and you want to cancel the relative path.
+
+        Returns:
+            str.
+        """
+        url = PolyaxonStore.URL.format(
+            namespace=self.namespace,
+            owner=self.owner,
+            project=self.project,
+            uuid=self.run_uuid,
+            subpath="artifacts",
+        )
+        url = "{host}/{url}".format(host=clean_host(self.client.config.host), url=url)
+
+        return PolyaxonStore(client=self).upload_dir(
+            url=url,
+            path=path,
+            files=files,
+            overwrite=overwrite,
+            relative_to=relative_to,
+        )
+
     @check_no_op
     @check_offline
     def get_artifacts_tree(self, path: str = ""):
@@ -781,7 +902,19 @@ class RunClient:
     def stop(self):
         """Stops the current run."""
         self.client.runs_v1.stop_run(
-            self.owner, self.project, self.run_uuid,
+            self.owner,
+            self.project,
+            self.run_uuid,
+        )
+
+    @check_no_op
+    @check_offline
+    def approve(self):
+        """Stops the current run."""
+        self.client.runs_v1.approve_run(
+            self.owner,
+            self.project,
+            self.run_uuid,
         )
 
     @check_no_op
@@ -789,7 +922,9 @@ class RunClient:
     def invalidate(self):
         """Invalidates the current run."""
         self.client.runs_v1.invalidate_run(
-            self.owner, self.project, self.run_uuid,
+            self.owner,
+            self.project,
+            self.run_uuid,
         )
 
     @check_no_op
@@ -906,7 +1041,29 @@ class RunClient:
             self._run_data.outputs = outputs
         self._update(patch_dict, async_req=async_req)
 
-    def _log_meta(self, reset: bool = False, async_req: bool = True, **meta):
+    def log_meta(self, reset: bool = False, async_req: bool = True, **meta):
+        """Logs meta_info for the current run.
+
+        > **Note**: Use carefully! The meta information is used by
+        Polyaxon internally to perform several information.
+
+        Polyaxon Client already uses this method to log information
+        about several events and artifacts, Polyaxon API/Scheduler uses
+        this information to set meta information about the run.
+
+        An example use case for this method is to update the concurrency
+        of a pipeline to increase/decrease the initial value:
+        ```python
+        >>> from polyaxon.client import RunClient
+        >>> client = RunClient()
+        >>> client.log_meta(concurrency=5)
+        ```
+
+        Args:
+            reset: bool, optional, if True, it will reset the whole meta info state.
+            async_req: bool, optional, default: False, execute request asynchronously.
+            meta: **kwargs, e.g. concurrency=10, has_flag=True, ...
+        """
         patch_dict = {"meta_info": meta}
         if reset is False:
             patch_dict["merge"] = True
@@ -948,7 +1105,7 @@ class RunClient:
         This method is only useful for manual runs outside of Polyaxon.
         </blockquote>
         """
-        self.log_status(polyaxon_sdk.V1Statuses.RUNNING, "Job is running")
+        self.log_status(polyaxon_sdk.V1Statuses.RUNNING, "Operation is running")
         self._run_data.status = polyaxon_sdk.V1Statuses.RUNNING
 
     @check_no_op
@@ -976,7 +1133,7 @@ class RunClient:
 
     @check_no_op
     @check_offline
-    def log_succeeded(self):
+    def log_succeeded(self, message="Operation has succeeded"):
         """Sets the current run to `succeeded` status.
 
         <blockquote class="info">
@@ -984,11 +1141,11 @@ class RunClient:
         This method is only useful for manual runs outside of Polyaxon.
         </blockquote>
         """
-        self.end("succeeded", "Job has succeeded")
+        self.end(polyaxon_sdk.V1Statuses.SUCCEEDED, message)
 
     @check_no_op
     @check_offline
-    def log_stopped(self):
+    def log_stopped(self, message="Operation is stopped"):
         """Sets the current run to `stopped` status.
 
         <blockquote class="info">
@@ -996,7 +1153,7 @@ class RunClient:
         This method is only useful for manual runs outside of Polyaxon.
         </blockquote>
         """
-        self.end("stopped", "Job is stopped")
+        self.end(polyaxon_sdk.V1Statuses.STOPPED, message)
 
     @check_no_op
     @check_offline
@@ -1012,7 +1169,9 @@ class RunClient:
             message: str, optional, message to log with this status.
             traceback: str, optional, reason for this status change.
         """
-        self.end(status="failed", message=message, traceback=traceback)
+        self.end(
+            status=polyaxon_sdk.V1Statuses.FAILED, message=message, traceback=traceback
+        )
 
     @check_no_op
     @check_offline
@@ -1125,7 +1284,11 @@ class RunClient:
     @check_no_op
     @check_offline
     def log_dir_ref(
-        self, path: str, name: str = None, is_input: bool = False, rel_path: str = None,
+        self,
+        path: str,
+        name: str = None,
+        is_input: bool = False,
+        rel_path: str = None,
     ):
         """Logs dir reference.
 
@@ -1173,7 +1336,7 @@ class RunClient:
             is_input=is_input,
         )
         self.log_artifact_lineage(body=artifact_run)
-        self._log_meta(has_tensorboard=True)
+        self.log_meta(has_tensorboard=True)
 
     @check_no_op
     @check_offline
@@ -1186,7 +1349,10 @@ class RunClient:
             body: dict or List[dict] or V1RunArtifact or List[V1RunArtifact], body of the lineage.
         """
         self.client.runs_v1.create_run_artifacts_lineage(
-            self.owner, self.project, self.run_uuid, body=body,
+            self.owner,
+            self.project,
+            self.run_uuid,
+            body=body,
         )
 
     @check_no_op
@@ -1194,7 +1360,9 @@ class RunClient:
     def get_namespace(self):
         """Fetches the run namespace."""
         return self.client.runs_v1.get_run_namespace(
-            self.owner, self.project, self.run_uuid,
+            self.owner,
+            self.project,
+            self.run_uuid,
         ).namespace
 
     @check_no_op
@@ -1214,9 +1382,9 @@ class RunClient:
 
         Args:
             query: str, optional, query filters, please refer to
-                [Project PQL](/docs/core/query-syntax/runs/#query)
+                [Project PQL](/docs/core/query-language/runs/#query)
             sort: str, optional, fields to order by, please refer to
-                [Project PQL](/docs/core/query-syntax/runs/#sort)
+                [Project PQL](/docs/core/query-language/runs/#sort)
             limit: int, optional, limit of runs to return.
             offset: int, optional, offset pages to paginate runs.
 
@@ -1237,9 +1405,9 @@ class RunClient:
 
         Args:
             query: str, optional, query filters, please refer to
-                [Project PQL](/docs/core/query-syntax/runs/#query)
+                [Project PQL](/docs/core/query-language/runs/#query)
             sort: str, optional, fields to order by, please refer to
-                [Project PQL](/docs/core/query-syntax/runs/#sort)
+                [Project PQL](/docs/core/query-language/runs/#sort)
             limit: int, optional, limit of runs to return.
             offset: int, optional, offset pages to paginate runs.
 
@@ -1258,13 +1426,18 @@ class RunClient:
 def get_run_logs(
     client: RunClient,
     hide_time: bool = False,
+    all_containers: bool = False,
     all_info: bool = False,
     follow: bool = False,
 ):
     def get_logs(last_file=None, last_time=None):
         try:
             response = client.get_logs(last_file=last_file, last_time=last_time)
-            get_logs_handler(show_timestamp=not hide_time, all_info=all_info)(response)
+            get_logs_handler(
+                show_timestamp=not hide_time,
+                all_containers=all_containers,
+                all_info=all_info,
+            )(response)
             return response
         except (ApiException, HTTPError) as e:
             if not follow:
