@@ -20,8 +20,7 @@ from concurrent import futures
 from typing import List, Optional
 
 from azure.core.exceptions import HttpResponseError
-from azure.storage.blob import BlobServiceClient
-from azure.storage.blob._models import BlobPrefix
+from azure.storage.blob import BlobPrefix, BlobServiceClient
 
 from polyaxon.connections.azure.base import (
     AzureService,
@@ -63,7 +62,8 @@ def get_blob_service_connection(
     )
     if connection_string:
         return BlobServiceClient.from_connection_string(
-            conn_str=connection_string, credential=account_key,
+            conn_str=connection_string,
+            credential=account_key,
         )
     if account_name:
         return BlobServiceClient(
