@@ -16,7 +16,7 @@
 
 import polyaxon_sdk
 
-from marshmallow import ValidationError, fields
+from marshmallow import INCLUDE, ValidationError, fields
 
 from polyaxon.connections.kinds import V1ConnectionKind
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig, BaseOneOfSchema
@@ -99,6 +99,7 @@ class V1HostConnection(BaseConfig, polyaxon_sdk.V1HostConnection):
 class GitConnectionSchema(BaseCamelSchema):
     url = fields.Str(allow_none=True)
     revision = fields.Str(allow_none=True)
+    flags = fields.List(fields.Str(), allow_none=True)
 
     @staticmethod
     def schema_config():
@@ -108,7 +109,7 @@ class GitConnectionSchema(BaseCamelSchema):
 class V1GitConnection(BaseConfig, polyaxon_sdk.V1GitConnection):
     SCHEMA = GitConnectionSchema
     IDENTIFIER = "git"
-    REDUCED_ATTRIBUTES = ["url", "revision"]
+    REDUCED_ATTRIBUTES = ["url", "revision", "flags"]
 
     def get_name(self):
         if self.url:
@@ -118,6 +119,73 @@ class V1GitConnection(BaseConfig, polyaxon_sdk.V1GitConnection):
     def patch(self, schema: "GitConnectionSchema"):
         self.url = schema.url or self.url
         self.revision = schema.revision or self.revision
+        self.flags = schema.flags or self.flags
+
+
+class CustomConnectionSchema(BaseCamelSchema):
+    class Meta(BaseCamelSchema.Meta):
+        unknown = INCLUDE
+
+    @staticmethod
+    def schema_config():
+        return V1CustomConnection
+
+
+class V1CustomConnection(BaseConfig):
+    UNKNOWN_BEHAVIOUR = INCLUDE
+    IDENTIFIER = "custom"
+    SCHEMA = CustomConnectionSchema
+
+    def __init__(self, **kwargs):
+        self._schema_keys = set([])
+        for k, v in kwargs.items():
+            self._schema_keys.add(k)
+            self.__setattr__(k, v)
+
+    @classmethod
+    def obj_to_dict(
+        cls,
+        obj,
+        humanize_values=False,
+        unknown=None,
+        include_kind=False,
+        include_version=False,
+    ):
+        value = super().obj_to_dict(
+            obj=obj,
+            humanize_values=humanize_values,
+            unknown=cls.UNKNOWN_BEHAVIOUR,
+            include_kind=include_kind,
+            include_version=include_version,
+        )
+        value.update({k: getattr(obj, k) for k in obj._schema_keys})
+        return value
+
+    @classmethod
+    def from_dict(cls, value, unknown=None):
+        return super().from_dict(value=value, unknown=cls.UNKNOWN_BEHAVIOUR)
+
+    def __eq__(self, other):
+        """Returns true if both objects are equal"""
+        if not isinstance(other, V1CustomConnection):
+            return False
+
+        return self.to_dict() == other.to_dict()
+
+    def patch_git(self, schema: "GitConnectionSchema"):
+        if schema.url:
+            if "url" not in self._schema_keys:
+                self._schema_keys.add("url")
+            setattr(self, "url", schema.url)
+        if schema.revision:
+            if "revision" not in self._schema_keys:
+                self._schema_keys.add("revision")
+            setattr(self, "revision", schema.url)
+
+        if schema.flags:
+            if "flags" not in self._schema_keys:
+                self._schema_keys.add("flags")
+            setattr(self, "flags", schema.flags)
 
 
 def validate_connection(kind, definition):
@@ -143,10 +211,16 @@ def validate_connection(kind, definition):
 class ConnectionSchema(BaseOneOfSchema):
     TYPE_FIELD = "kind"
     TYPE_FIELD_REMOVE = True
+    UNKNOWN_BEHAVIOUR = INCLUDE
+
+    class Meta:
+        unknown = INCLUDE
+
     SCHEMAS = {
         V1BucketConnection.IDENTIFIER: BucketConnectionSchema,
         V1ClaimConnection.IDENTIFIER: ClaimConnectionSchema,
         V1HostPathConnection.IDENTIFIER: HostPathConnectionSchema,
         V1HostConnection.IDENTIFIER: HostConnectionSchema,
         V1GitConnection.IDENTIFIER: GitConnectionSchema,
+        V1CustomConnection.IDENTIFIER: CustomConnectionSchema,
     }
