@@ -45,6 +45,22 @@ from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
 from polyaxon.schemas.types import ConnectionTypeSchema
 
 
+def validate_connections(artifacts_store, connections):
+    connections = connections or []
+
+    connection_names = set()
+
+    if artifacts_store:
+        connection_names.add(artifacts_store.name)
+
+    for c in connections:
+        if c.name in connection_names:
+            raise ValidationError(
+                "A connection with name `{}` must be unique.".format(c.name)
+            )
+        connection_names.add(c.name)
+
+
 def check_postgres(postgresql, external_services):
     postgresql_disabled = postgresql.enabled is False if postgresql else False
     external_postgresql = None
@@ -82,8 +98,9 @@ def check_rabbitmq(rabbitmq, external_services, broker):
 
 def check_redis(redis, external_services, broker):
     redis_enabled = redis and redis.enabled
+    redis_non_broker = redis and redis.non_broker
     external_redis = None
-    redis_borker = broker == "redis"
+    redis_broker = broker == "redis"
     if external_services:
         external_redis = external_services.redis
 
@@ -94,12 +111,12 @@ def check_redis(redis, external_services, broker):
         )
 
     redis_used = redis_enabled or external_redis
-    if redis_used and not redis_borker:
+    if redis_used and not redis_broker and not redis_non_broker:
         raise ValidationError(
             "redis is enabled but you are using a different broker backend!"
         )
 
-    return redis_used
+    return redis_used, not redis_non_broker
 
 
 def broker_is_required(services):
@@ -126,11 +143,12 @@ def validate_platform_deployment(
     postgresql, redis, rabbitmq, broker, scheduler, worker, beat, external_services
 ):
     check_postgres(postgresql, external_services)
-    redis_used = check_redis(redis, external_services, broker)
+    redis_used, redis_is_broker = check_redis(redis, external_services, broker)
     rabbitmq_used = check_rabbitmq(rabbitmq, external_services, broker)
-    if rabbitmq_used and redis_used:
+    if rabbitmq_used and redis_used and redis_is_broker:
         raise ValidationError(
-            "You can only enable rabbitmq or redis, you don't need to deploy both!"
+            "You only need to enable rabbitmq or redis for the broker, "
+            "you don't need to deploy both!"
         )
     broker_defined = rabbitmq_used or redis_used
     services = [scheduler, worker, beat]
@@ -141,7 +159,9 @@ def validate_platform_deployment(
 
 
 def validate_deployment_chart(
-    deployment_chart, agent, environment,
+    deployment_chart,
+    agent,
+    environment,
 ):
     if deployment_chart == DeploymentCharts.AGENT and not agent:
         raise ValidationError(
@@ -162,7 +182,7 @@ def validate_gateway(gateway):
     service_type = gateway.service.get("type")
     if service_type and service_type not in ServiceTypes.VALUES:
         raise ValidationError(
-            "Receive an invalid gateway service type: {}".format(service_type)
+            "Received an invalid gateway service type: {}".format(service_type)
         )
 
 
@@ -208,7 +228,9 @@ class DeploymentSchema(BaseCamelSchema):
     sidecar = fields.Nested(HelperServiceSchema, allow_none=True)
     tables_hook = fields.Nested(ServiceSchema, allow_none=True)
     clean_hooks = fields.Nested(ServiceSchema, allow_none=True)
+    api_hooks = fields.Nested(ServiceSchema, allow_none=True)
     hooks = fields.Nested(HooksSchema, allow_none=True)
+    flower = fields.Nested(ServiceSchema, allow_none=True)
     postgresql = fields.Nested(PostgresqlSchema, allow_none=True)
     redis = fields.Nested(RedisSchema, allow_none=True)
     rabbitmq = fields.Nested(RabbitmqSchema, data_key="rabbitmq-ha", allow_none=True)
@@ -219,11 +241,13 @@ class DeploymentSchema(BaseCamelSchema):
     image_pull_secrets = fields.List(fields.Str(), allow_none=True)
     host_name = fields.Str(allow_none=True)
     allowed_hosts = fields.List(fields.Str(), allow_none=True)
+    include_host_ips = fields.Bool(allow_none=True)
     intervals = fields.Nested(IntervalsSchema, allow_none=True)
     artifacts_store = fields.Nested(ConnectionTypeSchema, allow_none=True)
     connections = fields.List(fields.Nested(ConnectionTypeSchema), allow_none=True)
     notification_connections = fields.List(
-        fields.Nested(ConnectionTypeSchema), allow_none=True,
+        fields.Nested(ConnectionTypeSchema),
+        allow_none=True,
     )
     log_level = fields.Str(allow_none=True)
     security_context = fields.Nested(SecurityContextSchema, allow_none=True)
@@ -242,6 +266,10 @@ class DeploymentSchema(BaseCamelSchema):
     def schema_config():
         return DeploymentConfig
 
+    @validates_schema
+    def validate_connections(self, data, **kwargs):
+        validate_connections(data.get("artifacts_store"), data.get("connections"))
+
     @validates_schema
     def validate_deployment(self, data, **kwargs):
         validate_deployment_chart(
@@ -273,7 +301,9 @@ class DeploymentSchema(BaseCamelSchema):
                 worker=data.get("worker"),
                 beat=data.get("beat"),
                 tables_hook=data.get("tables_hook"),
+                api_hooks=data.get("api_hooks"),
                 hooks=data.get("hooks"),
+                flower=data.get("flower"),
                 postgresql=data.get("postgresql"),
                 redis=data.get("redis"),
                 rabbitmq=data.get("rabbitmq"),
@@ -327,7 +357,9 @@ class DeploymentConfig(BaseConfig):
         sidecar=None,
         tables_hook=None,
         clean_hooks=None,
+        api_hooks=None,
         hooks=None,
+        flower=None,
         postgresql=None,
         redis=None,
         rabbitmq=None,
@@ -338,6 +370,7 @@ class DeploymentConfig(BaseConfig):
         image_pull_secrets=None,
         host_name=None,
         allowed_hosts=None,
+        include_host_ips=None,
         intervals=None,
         artifacts_store=None,
         connections=None,
@@ -355,7 +388,9 @@ class DeploymentConfig(BaseConfig):
         include_chart_revision=None,
     ):
         validate_deployment_chart(
-            deployment_chart=deployment_chart, agent=agent, environment=environment,
+            deployment_chart=deployment_chart,
+            agent=agent,
+            environment=environment,
         )
         validate_platform_deployment(
             postgresql=postgresql,
@@ -404,7 +439,9 @@ class DeploymentConfig(BaseConfig):
         self.sidecar = sidecar
         self.tables_hook = tables_hook
         self.clean_hooks = clean_hooks
+        self.api_hooks = api_hooks
         self.hooks = hooks
+        self.flower = flower
         self.postgresql = postgresql
         self.redis = redis
         self.rabbitmq = rabbitmq
@@ -415,6 +452,7 @@ class DeploymentConfig(BaseConfig):
         self.image_pull_secrets = image_pull_secrets
         self.host_name = host_name
         self.allowed_hosts = allowed_hosts
+        self.include_host_ips = include_host_ips
         self.intervals = intervals
         self.artifacts_store = artifacts_store
         self.connections = connections
@@ -444,7 +482,9 @@ class DeploymentConfig(BaseConfig):
                 worker=worker,
                 beat=beat,
                 tables_hook=tables_hook,
+                api_hooks=api_hooks,
                 hooks=hooks,
+                flower=flower,
                 postgresql=postgresql,
                 redis=redis,
                 rabbitmq=rabbitmq,
