@@ -26,10 +26,10 @@ from polyaxon.schemas.cli.client_config import ClientConfig
 
 
 class ClientConfigManager(BaseConfigManager):
-    """Manages client configuration .polyaxonclient file."""
+    """Manages client configuration .client file."""
 
-    IS_GLOBAL = True
-    CONFIG_FILE_NAME = ".polyaxonclient"
+    VISIBILITY = BaseConfigManager.VISIBILITY_GLOBAL
+    CONFIG_FILE_NAME = ".client"
     CONFIG = ClientConfig
 
     @classmethod
@@ -39,9 +39,9 @@ class ClientConfigManager(BaseConfigManager):
 
         config = ConfigManager.read_configs(
             [
-                os.environ,
                 ConfigSpec(tmp_path, config_type=".json", check_if_exists=False),
                 ConfigSpec(user_path, config_type=".json", check_if_exists=False),
+                os.environ,
             ]
         )
         return ClientConfig.from_dict(config.data)
