@@ -23,12 +23,12 @@ from polyaxon.utils import constants
 from polyaxon.utils.formatting import Printer
 
 
-class ProjectManager(BaseConfigManager):
-    """Manages project configuration .polyaxonproject file."""
+class ProjectConfigManager(BaseConfigManager):
+    """Manages project configuration .project file."""
 
-    IS_GLOBAL = True
+    VISIBILITY = BaseConfigManager.VISIBILITY_ALL
     IS_POLYAXON_DIR = True
-    CONFIG_FILE_NAME = ".polyaxonproject"
+    CONFIG_FILE_NAME = ".project"
     CONFIG = V1Project
 
     @classmethod
@@ -36,7 +36,7 @@ class ProjectManager(BaseConfigManager):
         project = cls.get_config()
         if not project:
             Printer.print_error(
-                "Please initialize your project before uploading any code."
+                "No project was found, please initialize a project."
                 " {}".format(constants.INIT_COMMAND)
             )
             sys.exit(1)
