@@ -17,25 +17,42 @@
 import os
 
 from collections import OrderedDict
-from typing import Dict
+from typing import Dict, List
 
 from polyaxon.cli.errors import handle_cli_error
 from polyaxon.config_reader.spec import ConfigSpec
-from polyaxon.exceptions import PolyaxonfileError
-from polyaxon.polyaxonfile.manager import check_default_path, get_op_specification
+from polyaxon.exceptions import PolyaxonfileError, PolyaxonSchemaError
+from polyaxon.polyaxonfile.manager import (
+    get_op_specification,
+    is_supported_in_eager_mode,
+)
 from polyaxon.polyaxonfile.params import parse_params
 from polyaxon.polyaxonfile.specs import get_specification, kinds
-from polyaxon.polyflow import V1Operation
+from polyaxon.polyflow import V1Dag, V1Init, V1Operation
 from polyaxon.utils.formatting import Printer, dict_tabulate
 from polyaxon.utils.list_utils import to_list
 
 
+def collect_dag_components(dag: V1Dag, path_context: str = None):
+    """Collect components that cannot be resolved by the scheduler"""
+    for op in dag.operations:
+        op_name = op.name
+        if op.has_url_reference or op.has_path_reference:
+            try:
+                op = collect_references(op, path_context)
+            except Exception as e:
+                raise PolyaxonSchemaError(
+                    "Pipeline op with name `{}` requires a component with ref `{}`, "
+                    "the reference could not be resolved. Error: {}".format(
+                        op_name, op.hub_ref or op.url_ref or op.path_ref, e
+                    )
+                )
+
+
 def collect_references(config: V1Operation, path_context: str = None):
-    if config.has_component_reference or (
-        config.has_hub_reference and not config.has_public_hub_reference
-    ):
+    if config.has_component_reference:
         return config
-    elif config.has_public_hub_reference:
+    elif config.has_hub_reference:
         component = ConfigSpec.get_from(config.hub_ref, "hub").read()
     elif config.has_url_reference:
         component = ConfigSpec.get_from(config.url_ref, "url").read()
@@ -63,6 +80,8 @@ def collect_references(config: V1Operation, path_context: str = None):
             )
         )
     config.component = component
+    if component.is_dag_run:
+        component.run.collect_components()
     return config
 
 
@@ -72,18 +91,22 @@ def check_polyaxonfile(
     url: str = None,
     hub: str = None,
     params: Dict = None,
-    profile: str = None,
+    presets: List[str] = None,
     queue: str = None,
     nocache: bool = None,
-    log: bool = True,
-    eager_hub: bool = True,
+    cache: bool = None,
+    verbose: bool = True,
     is_cli: bool = True,
     to_op: bool = True,
+    validate_params: bool = True,
+    eager: bool = False,
+    git_init: V1Init = None,
+    ignore_template: bool = False,
 ):
-    if sum([1 for i in [polyaxonfile, python_module, url, hub] if i]) > 1:
+    if sum([1 for i in [python_module, url, hub] if i]) > 1:
         message = (
             "You can only use one and only one option: "
-            "hub, url, module, or path ro polyaxonfile.".format(hub)
+            "hub, url, or a python module.".format(hub)
         )
         if is_cli:
             Printer.print_error(message, sys_exit=True)
@@ -92,7 +115,14 @@ def check_polyaxonfile(
     if not any([polyaxonfile, python_module, url, hub]):
         polyaxonfile = check_default_path(path=".")
     if not any([polyaxonfile, python_module, url, hub]):
-        polyaxonfile = ""
+        message = (
+            "Something went wrong, `check_polyaxonfile` was called without a polyaxonfile, "
+            "a hub component reference, a url or a python module."
+        )
+        if is_cli:
+            Printer.print_error(message, sys_exit=True)
+        else:
+            raise PolyaxonfileError(message)
     if hub and not to_op:
         message = "Something went wrong, calling hub component `{}` without operation.".format(
             hub
@@ -111,50 +141,71 @@ def check_polyaxonfile(
     if not any([os.path.isfile(f) for f in polyaxonfile]) and not any(
         [python_module, url, hub]
     ):
-        message = (
-            "Please pass a valid polyaxonfile, a python module, url, or component name"
-        )
+        message = "Please pass a valid polyaxonfile, a python module, a url, or a component name"
         if is_cli:
             Printer.print_error(message, sys_exit=True)
         else:
             raise PolyaxonfileError(message)
 
     try:
-        plx_file = None
         path_context = None
-        public_hub = hub and "/" not in hub
 
-        if not hub or (public_hub and eager_hub):
-            if python_module:
-                path_context = python_module[0]
-                plx_file = ConfigSpec.get_from(python_module, config_type=".py").read()
+        # Collecting manifests (TODO: in the future we should collect hub directly on Polyaxon)
+        if python_module:
+            path_context = python_module
+            plx_file = (
+                ConfigSpec.get_from(python_module, config_type=".py")
+                .read()
+                .to_dict(include_kind=True, include_version=True)
+            )
+        elif url:
+            plx_file = ConfigSpec.get_from(url, "url").read()
+        elif hub:
+            plx_file = ConfigSpec.get_from(hub, "hub").read()
+        else:
+            path_context = polyaxonfile.pop(0)
+            plx_file = ConfigSpec.read_from(path_context)
 
-            elif url:
-                plx_file = ConfigSpec.get_from(url, "url").read()
+        plx_file = get_specification(data=plx_file)
+        if plx_file.kind == kinds.OPERATION:
+            plx_file = collect_references(plx_file, path_context)
+            plx_component = plx_file.component
+        else:
+            plx_component = plx_file
 
-            elif hub:
-                plx_file = ConfigSpec.get_from(hub, "hub").read()
-
-            else:
-                path_context = polyaxonfile[0]
-                plx_file = ConfigSpec.read_from(polyaxonfile)
-
-            plx_file = get_specification(data=plx_file)
-            if plx_file.kind == kinds.OPERATION:
-                plx_file = collect_references(plx_file, path_context)
+        if plx_component.is_dag_run:
+            collect_dag_components(plx_component.run, path_context)
 
         if to_op or hub:
             plx_file = get_op_specification(
                 hub=hub,
                 config=plx_file,
                 params=parsed_params,
-                profile=profile,
+                presets=presets,
                 queue=queue,
                 nocache=nocache,
-                path_context=path_context,
+                cache=cache,
+                validate_params=validate_params,
+                preset_files=polyaxonfile,
+                git_init=git_init,
             )
-        if log and not is_cli:
+        if verbose and is_cli:
             Printer.print_success("Polyaxonfile valid")
+        if ignore_template:
+            plx_file.disable_template()
+        if plx_file.is_template():
+            template_message = "This polyaxonfile was marked as template by the owner:"
+            if plx_file.template.description:
+                template_message += "\ntemplate description: {}".format(
+                    plx_file.template.description
+                )
+            if plx_file.template.fields:
+                template_message += "\ntemplate fields that need changes: {}".format(
+                    plx_file.template.fields
+                )
+            Printer.print_warning(template_message)
+        if eager:
+            is_supported_in_eager_mode(spec=plx_file)
         return plx_file
     except Exception as e:
         message = "Polyaxonfile is not valid."
@@ -186,3 +237,23 @@ def get_matrix_info(kind, concurrency, early_stopping=False, **kwargs):
         info["Num of runs to create"] = kwargs["num_runs"]
 
     dict_tabulate(info)
+
+
+DEFAULT_POLYAXON_FILE_NAME = [
+    "polyaxon",
+    "polyaxonci",
+    "polyaxon-ci",
+    "polyaxon.ci",
+    "polyaxonfile",
+]
+
+DEFAULT_POLYAXON_FILE_EXTENSION = ["yaml", "yml", "json"]
+
+
+def check_default_path(path):
+    path = os.path.abspath(path)
+    for filename in DEFAULT_POLYAXON_FILE_NAME:
+        for ext in DEFAULT_POLYAXON_FILE_EXTENSION:
+            filepath = os.path.join(path, "{}.{}".format(filename, ext))
+            if os.path.isfile(filepath):
+                return filepath
