@@ -16,7 +16,9 @@
 
 from marshmallow import fields, validate
 
+from polyaxon.polyflow.actions import ActionSchema
 from polyaxon.polyflow.cache import CacheSchema
+from polyaxon.polyflow.hooks import HookSchema
 from polyaxon.polyflow.plugins import PluginsSchema
 from polyaxon.polyflow.termination import TerminationSchema
 from polyaxon.schemas.base import NAME_REGEX, BaseCamelSchema, BaseConfig
@@ -29,11 +31,14 @@ class BaseComponentSchema(BaseCamelSchema):
     name = fields.Str(validate=validate.Regexp(regex=NAME_REGEX), allow_none=True)
     description = fields.Str(allow_none=True)
     tags = fields.List(fields.Str(), allow_none=True)
-    profile = RefOrObject(fields.Str(allow_none=True))
+    presets = fields.List(fields.Str(allow_none=True))
     queue = RefOrObject(fields.Str(allow_none=True))
     cache = fields.Nested(CacheSchema, allow_none=True)
     termination = fields.Nested(TerminationSchema, allow_none=True)
     plugins = fields.Nested(PluginsSchema, allow_none=True)
+    actions = fields.List(fields.Nested(ActionSchema), allow_none=True)
+    hooks = fields.List(fields.Nested(HookSchema), allow_none=True)
+    is_approved = fields.Bool(allow_none=True)
 
     @staticmethod
     def schema_config():
@@ -48,9 +53,12 @@ class BaseComponent(BaseConfig):
         "name",
         "description",
         "tags",
-        "profile",
+        "presets",
         "queue",
         "cache",
         "termination",
         "plugins",
+        "actions",
+        "hooks",
+        "isApproved",
     ]
