@@ -24,6 +24,13 @@ from polyaxon.exceptions import PolyaxonSchemaError
 from polyaxon.parser import parser
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
 
+IO_NAME_BLACK_LIST = ["globals", "params", "connections"]
+IO_NAME_ERROR = (
+    "Received an input/output with a name in {}, "
+    "please use a different name that does "
+    "not already taken by the context".format(IO_NAME_BLACK_LIST)
+)
+
 
 def validate_io_value(
     name: str,
@@ -78,14 +85,16 @@ def validate_io(name, iotype, value, is_optional, is_list, is_flag, options):
 
     if is_flag and iotype != types.BOOL:
         raise ValidationError(
-            "IO type `{}` cannot be a flag, iut must be a `{}`".format(
+            "IO type `{}` cannot be a flag, it must be of type `{}`".format(
                 iotype, types.BOOL
             )
         )
 
 
 class IOSchema(BaseCamelSchema):
-    name = fields.Str(required=True)
+    name = fields.Str(
+        required=True, validate=validate.NoneOf(IO_NAME_BLACK_LIST, error=IO_NAME_ERROR)
+    )
     description = fields.Str(allow_none=True)
     iotype = fields.Str(
         allow_none=True, data_key="type", validate=validate.OneOf(types.VALUES)
@@ -94,8 +103,11 @@ class IOSchema(BaseCamelSchema):
     is_optional = fields.Bool(allow_none=True)
     is_list = fields.Bool(allow_none=True)
     is_flag = fields.Bool(allow_none=True)
+    arg_format = fields.Str(allow_none=True)
     delay_validation = fields.Bool(allow_none=True)
     options = fields.List(fields.Raw(), allow_none=True)
+    connection = fields.Str(allow_none=True)
+    to_init = fields.Bool(allow_none=True)
 
     @staticmethod
     def schema_config():
@@ -121,7 +133,7 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
     inputs and outputs types are used to validate the flow of information
     going from one operation to another.
 
-    The final value of an input / output can be resolved
+    The final value of an input/output can be resolved
     from [params](/docs/core/specification/params/), or from other values in
     the [context](/docs/core/specification/context/).
 
@@ -133,8 +145,16 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
     An input/output section includes a name, a description, a type to check the value passed,
     a flag to tell if the input/output is optional, and a default value if it's optional.
 
-    For inputs with type `bool`, users can additionally use
-    the field `isFlag` which will transform the input to a flag.
+    Sometimes users prefer to pass a param to the `command` or `args`
+    section only if the value is not null. Polyaxon provides a way to do that using
+    `{{ params.PARAM_NAME.as_arg }}`,
+    this will be empty if the value is null or `--PARAM_NAME=value` if the value is not null.
+    If the value is of type bool, it will be `--PARAM_NAME`.
+    It's also possible to control how the param should be
+    converted to an argument using the `arg_format`.
+
+    To learn how to pass valid values,
+    please check the [param section](/docs/core/specification/params/).
 
     Args:
         name: str
@@ -146,8 +166,11 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
         is_optional: bool, optional
         is_list: bool, optional
         is_flag: bool, optional
+        arg_format: str, optional
         delay_validation: bool, optional
         options: List[any], optional
+        connection: str, optional
+        to_init: bool, optional
 
     ## YAML usage
 
@@ -159,7 +182,6 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
     >>>     value: MeanSquaredError
     >>>   - name: preprocess
     >>>     type: bool
-    >>>     isFlag: true
     >>> outputs:
     >>>   - name: accuracy
     >>>     type: float
@@ -184,7 +206,6 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
     >>>         name="preprocess",
     >>>         iotype=types.BOOL,
     >>>         description="A flag to preprocess data before training",
-    >>>         is_flag=True
     >>>     )
     >>> ]
     >>> outputs = [
@@ -202,14 +223,14 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
     These inputs/outputs declarations can be used to pass values to our program:
 
     ```bash
-     ... --loss={{ loss }} {{ preprocess }}
+     ... --loss={{ loss }} {{ params.preprocess.as_arg }}
     ```
 
     ## Fields
 
     ### name
 
-    The input / output name.
+    The input/output name.
 
     the name must be a valid slug, and cannot include dots `.`.
 
@@ -220,7 +241,7 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
 
     ### description
 
-    An optional description for the input / output.
+    An optional description for the input/output.
 
     ```yaml
     >>> inputs:
@@ -230,7 +251,7 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
 
     ### type
 
-    The type of the input / output. The type will be used to validate the value
+    The type of the input/output. The type will be used to validate the value
 
     ```yaml
     >>> inputs:
@@ -279,9 +300,9 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
     >>>     value: 1.1
     ```
 
-    ### is_optional
+    ### isOptional
 
-    A flag to tell if an input / output is optional.
+    A flag to tell if an input/output is optional.
 
     ```yaml
     >>> inputs:
@@ -292,9 +313,9 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
     >>>     isOptional: true
     ```
 
-    ### is_list
+    ### isList
 
-    A flag to tell if an input / output is a list of the type passed.
+    A flag to tell if an input/output is a list of the type passed.
 
     ```yaml
     >>> inputs:
@@ -306,40 +327,102 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
     In this case the input name `learning_rates` will expect a value of type `List[float]`,
     e.g. [0.1 0.01, 0.0001]
 
-    ### is_flag
+    ### argFormat
 
-    A flag to tell if an input / output is a a flag. This only works and makes sense for inputs
-    of type `bool`.
+    A key to control how to convert an input/output to a CLI argument if the value is not null,
+    the default behavior:
 
-    When this flag is enabled, it will turn the usage of the input to `--...`
+      * For bool type: If the resolved value of the input is True,
+        `"{{ params.PARAM_NAME.as_arg }}"` will be resolved to `"--PARAM_NAME"`
+        otherwise it will be an empty string `""`.
+      * For non-bool types: If the resolved value of the input is not null,
+      `"{{ params.PARAM_NAME.as_arg }}"` will be resolved to `"--PARAM_NAME=value"`
+      otherwise it will be an empty string `""`.
+
+    Let's look at the flowing example:
 
     ```yaml
     >>> inputs:
+    >>>   - name: lr
+    >>>     type: float
     >>>   - name: check
     >>>     type: bool
-    >>>     isFlag: true
     ```
 
+    **This manifest**:
+
     ```yaml
     >>> container:
-    >>>    command: ["run", "model.py", "--param1=1.1", "{{ check }}"]
+    >>>    command: ["{{ lr }}", "{{ check }}"]
     ```
 
-    If the resolved value of the input `check` is True, `"{{ check }}"`
-    will be resolved to `"--check"` otherwise it will be an empty string `""`.
+    Will be transformed to:
+
+    ```yaml
+    >>> container:
+    >>>    command: ["0.01", "true"]
+    ```
+
+    **This manifest**:
+
+    ```yaml
+    >>> container:
+    >>>    command: ["{{ params.lr.as_arg }}", "{{ params.check.as_arg }}"]
+    ```
+
+    Will be transformed to:
+
+    ```yaml
+    >>> container:
+    >>>    command: ["--lr=0.01", "--check"]
+    ```
+
+    Changing the behavior with `argFormat`:
+
+    ```yaml
+    >>> inputs:
+    >>>   - name: lr
+    >>>     type: float
+    >>>     argFormat: "lr={{ lr }}"
+    >>>   - name: check
+    >>>     type: bool
+    >>>     argFormat: "{{ 1 if check else 0 }}"
+    ```
+
+    **This manifest**:
+
+    ```yaml
+    >>> container:
+    >>>    command: ["{{ params.lr.as_arg }}", "{{ params.check.as_arg }}"]
+    ```
+
+    Will be transformed to:
+
+    ```yaml
+    >>> container:
+    >>>    command: ["lr=0.01", "1"]
+    ```
 
     ### delayValidation
 
-    A flag to tell if an input / output should not be
+    A flag to tell if an input/output should not be
     validated at compilation or resolution time.
 
     This flag is enabled by default for outputs, since they can only be
     resolved after or during the run. To request validation at compilation time for outputs,
-    you need set this flag to `False`.
+    you need to set this flag to `False`.
+
+    ### connection
+
+    A connection to use with the input/outputs.
+
+    ### toInit
+
+    if True, it will be converted to an init container.
 
     ### options
 
-    Options allows to pass a list of values that will be used to validate any passed params.
+    Options allow to pass a list of values that will be used to validate any passed params.
 
     ```yaml
     >>> inputs:
@@ -350,7 +433,7 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
     >>>     options: [1.1, 2.2, 3.3]
     ```
 
-    If you pass the value `4.4` for learning rate it will raise a validation error.
+    If you pass the value `4.4` for the learning rate it will raise a validation error.
 
     ## Example
 
@@ -401,13 +484,13 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
 
     ### Running a typed component using the CLI
 
-    Using the Polyaxon CLI we can now run this compoennt and override the inputs' default values:
+    Using the Polyaxon CLI we can now run this component and override the inputs' default values:
 
     ```bash
     polyaxon run -f polyaxonfile.yaml -P activation=sigmoid -P dropout=0.4
     ```
 
-    this will result in an run where the params are passed and validated against the inputs types.
+    this will result in a run where the params are passed and validated against the inputs' types.
 
     ### Required inputs
 
@@ -441,8 +524,11 @@ class V1IO(BaseConfig, polyaxon_sdk.V1IO):
         "isOptional",
         "isFlag",
         "isList",
+        "argFormat",
         "delayValidation",
         "options",
+        "connection",
+        "toInit",
     ]
 
     def validate_value(self, value: Any, parse: bool = True):
