@@ -18,12 +18,16 @@ import polyaxon_sdk
 
 from marshmallow import ValidationError, fields, validate, validates_schema
 
+from polyaxon.containers.names import MAIN_JOB_CONTAINER
+from polyaxon.k8s import k8s_schemas
 from polyaxon.polyflow.early_stopping import EarlyStoppingSchema
+from polyaxon.polyflow.matrix.base import BaseSearchConfig
 from polyaxon.polyflow.matrix.kinds import V1MatrixKind
-from polyaxon.polyflow.matrix.params import MatrixSchema
+from polyaxon.polyflow.matrix.params import HpParamSchema
 from polyaxon.polyflow.optimization import OptimizationMetricSchema
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
 from polyaxon.schemas.fields.ref_or_obj import RefOrObject
+from polyaxon.schemas.fields.swagger import SwaggerField
 
 
 class AcquisitionFunctions:
@@ -184,13 +188,18 @@ class BayesSchema(BaseCamelSchema):
     kind = fields.Str(allow_none=True, validate=validate.Equal(V1MatrixKind.BAYES))
     utility_function = fields.Nested(UtilityFunctionSchema, allow_none=True)
     num_initial_runs = RefOrObject(fields.Int(), required=True)
-    num_iterations = RefOrObject(fields.Int(), required=True)
+    max_iterations = RefOrObject(fields.Int(validate=validate.Range(min=1)))
     metric = fields.Nested(OptimizationMetricSchema, required=True)
     params = fields.Dict(
-        keys=fields.Str(), values=fields.Nested(MatrixSchema), required=True
+        keys=fields.Str(), values=fields.Nested(HpParamSchema), required=True
     )
     seed = RefOrObject(fields.Int(allow_none=True))
     concurrency = fields.Int(allow_none=True)
+    container = SwaggerField(
+        cls=k8s_schemas.V1Container,
+        defaults={"name": MAIN_JOB_CONTAINER},
+        allow_none=True,
+    )
     early_stopping = fields.Nested(EarlyStoppingSchema, many=True, allow_none=True)
 
     @staticmethod
@@ -203,7 +212,7 @@ class BayesSchema(BaseCamelSchema):
         validate_matrix(data.get("params"))
 
 
-class V1Bayes(BaseConfig, polyaxon_sdk.V1Bayes):
+class V1Bayes(BaseSearchConfig, polyaxon_sdk.V1Bayes):
     """Bayesian optimization is an extremely powerful technique.
     The main idea behind it is to compute a posterior distribution
     over the objective function based on the data, and then select good points
@@ -217,7 +226,7 @@ class V1Bayes(BaseConfig, polyaxon_sdk.V1Bayes):
         kind: string, should be equal to `bayes`
         utility_function: UtilityFunctionConfig
         num_initial_runs: int
-        num_iterations: int
+        max_iterations: int
         metric: V1OptimizationMetric
         params: List[Dict[str,
         [params](/docs/automation/optimization-engine/params/#discrete-values)]]
@@ -233,7 +242,7 @@ class V1Bayes(BaseConfig, polyaxon_sdk.V1Bayes):
     >>>   kind: bayes
     >>>   utilityFunction:
     >>>   numInitialRuns:
-    >>>   numIterations:
+    >>>   maxIterations:
     >>>   metric:
     >>>   params:
     >>>   seed:
@@ -252,8 +261,8 @@ class V1Bayes(BaseConfig, polyaxon_sdk.V1Bayes):
     >>> matrix = V1Bayes(
     >>>   concurrency=20,
     >>>   utility_function=UtilityFunctionConfig(...),
-    >>>   numInitialRuns=40,
-    >>>   numIterations=20,
+    >>>   num_initial_runs=40,
+    >>>   max_iterations=20,
     >>>   params={"param1": V1HpLogSpace(...), "param2": V1HpChoice(...), ... },
     >>>   metric=V1OptimizationMetric(name="loss", optimization=V1Optimization.MINIMIZE),
     >>>   early_stopping=[V1FailureEarlyStopping(...), V1MetricEarlyStopping(...)]
@@ -353,7 +362,7 @@ class V1Bayes(BaseConfig, polyaxon_sdk.V1Bayes):
     >>>   numInitialRuns: 40
     ```
 
-    ### numIterations
+    ### maxIterations
 
     After creating the first set of random observations,
     the algorithm will use these results to update
@@ -372,7 +381,7 @@ class V1Bayes(BaseConfig, polyaxon_sdk.V1Bayes):
     ```yaml
     >>> matrix:
     >>>   kind: bayes
-    >>>   numIterations: 15
+    >>>   maxIterations: 15
     ```
 
     This configuration will make 15 suggestions based on the historical values,
@@ -436,6 +445,16 @@ class V1Bayes(BaseConfig, polyaxon_sdk.V1Bayes):
     For more details please check the
     [early stopping section](/docs/automation/helpers/early-stopping/).
 
+    ### container
+
+    The container with the logic for creating new suggestions based on bayesian optimization,
+    users can override this section to provide different resources requirements for the tuner.
+
+    ```yaml
+    >>> matrix:
+    >>>   kind: bayes
+    >>>   container: ...
+    ```
 
     ## Example
 
@@ -491,4 +510,13 @@ class V1Bayes(BaseConfig, polyaxon_sdk.V1Bayes):
 
     SCHEMA = BayesSchema
     IDENTIFIER = V1MatrixKind.BAYES
-    REDUCED_ATTRIBUTES = ["seed", "concurrency", "earlyStopping"]
+    REDUCED_ATTRIBUTES = ["seed", "concurrency", "earlyStopping", "container"]
+
+    def create_iteration(self, iteration: int = None) -> int:
+        if iteration is None:
+            return 0
+        return iteration + 1
+
+    def should_reschedule(self, iteration):
+        """Return a boolean to indicate if we need to reschedule another iteration."""
+        return iteration < self.max_iterations
