@@ -18,26 +18,36 @@ import polyaxon_sdk
 
 from marshmallow import fields, validate
 
+from polyaxon.containers.names import MAIN_JOB_CONTAINER
+from polyaxon.k8s import k8s_schemas
 from polyaxon.polyflow.early_stopping import EarlyStoppingSchema
+from polyaxon.polyflow.matrix.base import BaseSearchConfig
 from polyaxon.polyflow.matrix.kinds import V1MatrixKind
-from polyaxon.polyflow.matrix.params import MatrixSchema
-from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
+from polyaxon.polyflow.matrix.params import HpParamSchema
+from polyaxon.schemas.base import BaseCamelSchema
 from polyaxon.schemas.fields.ref_or_obj import RefOrObject
+from polyaxon.schemas.fields.swagger import SwaggerField
 
 
 class HyperoptSchema(BaseCamelSchema):
     kind = fields.Str(allow_none=True, validate=validate.Equal(V1MatrixKind.HYPEROPT))
+    max_iterations = RefOrObject(fields.Int(allow_none=True))
     algorithm = fields.Str(
         allow_none=True, validate=validate.OneOf(["tpe", "rand", "anneal"])
     )
     params = fields.Dict(
-        keys=fields.Str(), values=fields.Nested(MatrixSchema), required=True
+        keys=fields.Str(), values=fields.Nested(HpParamSchema), required=True
     )
     num_runs = RefOrObject(
         fields.Int(required=True, validate=validate.Range(min=1)), required=True
     )
     seed = RefOrObject(fields.Int(allow_none=True))
     concurrency = fields.Int(allow_none=True)
+    container = SwaggerField(
+        cls=k8s_schemas.V1Container,
+        defaults={"name": MAIN_JOB_CONTAINER},
+        allow_none=True,
+    )
     early_stopping = fields.Nested(EarlyStoppingSchema, many=True, allow_none=True)
 
     @staticmethod
@@ -45,7 +55,7 @@ class HyperoptSchema(BaseCamelSchema):
         return V1Hyperopt
 
 
-class V1Hyperopt(BaseConfig, polyaxon_sdk.V1Hyperopt):
+class V1Hyperopt(BaseSearchConfig, polyaxon_sdk.V1Hyperopt):
     """Hyperopt is a search algorithm that is backed by the
     [Hyperopt](http://hyperopt.github.io/hyperopt/) library
     to perform sequential model-based hyperparameter optimization.
@@ -57,6 +67,7 @@ class V1Hyperopt(BaseConfig, polyaxon_sdk.V1Hyperopt):
         algorithm: str, one of tpe, rand, anneal
         params: List[Dict[str,
         [params](/docs/automation/optimization-engine/params/#discrete-values)]]
+        maxIterations: int, optional
         concurrency: int, optional
         num_runs: int, optional
         seed: int, optional
@@ -69,6 +80,7 @@ class V1Hyperopt(BaseConfig, polyaxon_sdk.V1Hyperopt):
     >>> matrix:
     >>>   kind: hyperopt
     >>>   algorithm:
+    >>>   maxIterations:
     >>>   concurrency:
     >>>   params:
     >>>   numRuns:
@@ -168,6 +180,16 @@ class V1Hyperopt(BaseConfig, polyaxon_sdk.V1Hyperopt):
     >>>   numRuns: 5
     ```
 
+    ### maxIterations
+
+    Maximum number of iterations to run the process of \\-> suggestions -> training ->\\
+
+    ```yaml
+    >>> matrix:
+    >>>   kind: hyperopt
+    >>>   maxIterations: 5
+    ```
+
     ### seed
 
     Since this algorithm uses random generators,
@@ -191,8 +213,36 @@ class V1Hyperopt(BaseConfig, polyaxon_sdk.V1Hyperopt):
     >>>   kind: hyperopt
     >>>   earlyStopping: ...
     ```
+
+    ### container
+
+    The container with the logic for creating new suggestions based on bayesian optimization,
+    users can override this section to provide different resources requirements for the tuner.
+
+    ```yaml
+    >>> matrix:
+    >>>   kind: hyperopt
+    >>>   container: ...
+    ```
     """
 
     SCHEMA = HyperoptSchema
     IDENTIFIER = V1MatrixKind.HYPEROPT
-    REDUCED_ATTRIBUTES = ["numRuns", "seed", "concurrency", "earlyStopping"]
+    REDUCED_ATTRIBUTES = [
+        "numRuns",
+        "seed",
+        "concurrency",
+        "earlyStopping",
+        "container",
+    ]
+
+    def create_iteration(self, iteration: int = None) -> int:
+        if iteration is None:
+            return 0
+        return iteration + 1
+
+    def should_reschedule(self, iteration):
+        """Return a boolean to indicate if we need to reschedule another iteration."""
+        if not self.max_iterations:
+            return True
+        return iteration < self.max_iterations
