@@ -13,16 +13,18 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 import uuid
 
 from collections import namedtuple
 from typing import Dict, Optional
 
 import polyaxon_sdk
+import ujson
 
 from marshmallow import ValidationError, fields, validates_schema
 
+from polyaxon import types
+from polyaxon.polyflow.init import V1Init
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
 from polyaxon.schemas.fields.params import PARAM_REGEX
 
@@ -64,7 +66,7 @@ DAG_ENTITY_REF = "_"
 ENTITIES = {OPS, RUNS}
 
 
-def validate_param_value(value, search, ref):
+def validate_param_value(value, search, ref, to_init, context_only):
     if search and ref:
         raise ValidationError(
             "Only one field `ref` or `search` is possible, received both:\n"
@@ -78,11 +80,20 @@ def validate_param_value(value, search, ref):
             )
         )
 
+    if to_init and context_only:
+        raise ValidationError(
+            "Params cannot use `to_init` and `context_only` at the same time, "
+            "params require valid type be turned to an initializer automatically! "
+            "Please set an input with a type to use the `to_init` field, "
+            "or turn this param to an init manually."
+        )
+
 
 class ParamSearchSchema(BaseCamelSchema):
     query = fields.Str(required=True)
     sort = fields.Str(allow_none=True)
     limit = fields.Int(allow_none=True)
+    offset = fields.Int(allow_none=True)
 
     @staticmethod
     def schema_config():
@@ -95,14 +106,17 @@ class V1ParamSearch(BaseConfig, polyaxon_sdk.V1ParamSearch):
     REDUCED_ATTRIBUTES = [
         "sort",
         "limit",
+        "offset",
     ]
 
 
 class ParamSchema(BaseCamelSchema):
-    value = fields.Raw(required=True)
+    value = fields.Raw(required=True, allow_none=True)
     search = fields.Nested(ParamSearchSchema, allow_none=True)
     ref = fields.Str(allow_none=True)
     context_only = fields.Bool(allow_none=True)
+    connection = fields.Str(allow_none=True)
+    to_init = fields.Bool(allow_none=True)
 
     @staticmethod
     def schema_config():
@@ -114,6 +128,8 @@ class ParamSchema(BaseCamelSchema):
             value=values.get("value"),
             search=values.get("search"),
             ref=values.get("ref"),
+            context_only=values.get("context_only"),
+            to_init=values.get("to_init"),
         )
 
 
@@ -135,10 +151,12 @@ class V1Param(BaseConfig, polyaxon_sdk.V1Param):
     defined in the [component](/docs/core/specification/component/)
 
     Args:
-         * value: any
-         * search: V1SearchParam, optional
-         * ref: str, optional
-         * context_only: bool, optional
+         value: any
+         search: V1ParamSearch, optional
+         ref: str, optional
+         context_only: bool, optional
+         connection: str, optional
+         to_init: bool, optional
 
     ## YAML usage
 
@@ -260,6 +278,16 @@ class V1Param(BaseConfig, polyaxon_sdk.V1Param):
     Polyaxon will not check if this param was required by an input/output,
     and will inject it automatically in the context to be used.
     You can use for example `{{ convolutions.conv1 }}` in the specification.
+
+    ### connection
+
+    A connection to use with the parame.
+    if the initial Input/Output definition has a predefined connection and this connection
+    is provided, it will override the that value and will be added to the context.
+
+    ### toInit
+
+    if True the param will be converted to an init container.
     """
 
     SCHEMA = ParamSchema
@@ -268,11 +296,17 @@ class V1Param(BaseConfig, polyaxon_sdk.V1Param):
         "search",
         "ref",
         "contextOnly",
+        "connection",
+        "toInit",
     ]
 
     def validate(self):
         validate_param_value(
-            value=self.value, search=self.search, ref=self.ref,
+            value=self.value,
+            search=self.search,
+            ref=self.ref,
+            to_init=self.to_init,
+            context_only=self.context_only,
         )
 
     @property
@@ -334,7 +368,15 @@ class V1Param(BaseConfig, polyaxon_sdk.V1Param):
             return ""
         return "{}.{}".format(self.ref, self.value)
 
-    def get_spec(self, name: str, iotype: str, is_flag: bool, is_list: bool):
+    def get_spec(
+        self,
+        name: str,
+        iotype: str,
+        is_flag: bool,
+        is_list: bool,
+        is_context: bool,
+        arg_format: str,
+    ):
         """
         Checks if the value is param ref and validates it.
 
@@ -412,17 +454,103 @@ class V1Param(BaseConfig, polyaxon_sdk.V1Param):
                     )
 
         return ParamSpec(
-            name=name, iotype=iotype, param=self, is_flag=is_flag, is_list=is_list
+            name=name,
+            iotype=iotype,
+            param=self,
+            is_flag=is_flag,
+            is_list=is_list,
+            is_context=is_context,
+            arg_format=arg_format,
         )
 
 
-class ParamSpec(namedtuple("ParamSpec", "name iotype param is_flag is_list")):
-    @property
-    def display_value(self):
+class ParamSpec(
+    namedtuple("ParamSpec", "name iotype param is_flag is_list is_context arg_format")
+):
+    def get_display_value(self):
         if self.is_flag:
             return "--{}".format(self.name) if self.param.value else ""
         return self.param.value
 
+    def __repr__(self):
+        if self.is_flag:
+            return self.get_display_value()
+        return ujson.dumps(self.param.value) if self.param.value is not None else ""
+
+    def as_str(self):
+        return str(self)
+
+    def as_arg(self):
+        if self.arg_format:
+            from polyaxon.polyaxonfile.specs.libs.parser import Parser
+
+            return (
+                Parser.parse_expression(self.arg_format, {self.name: self.param.value})
+                if self.param.value is not None
+                else ""
+            )
+        if self.iotype == types.BOOL:
+            return "--{}".format(self.name) if self.param.value else ""
+        return (
+            "--{}={}".format(self.name.replace("_", "-"), self.as_str())
+            if self.param.value is not None
+            else ""
+        )
+
+    def to_parsed_param(self):
+        parsed_param = {
+            "connection": self.param.connection,
+            "value": self.param.value,
+            "type": self.iotype,
+            "as_str": self.as_str(),
+            "as_arg": self.as_arg(),
+        }
+        return parsed_param
+
+    def validate_to_init(self) -> bool:
+        if not self.param.to_init:
+            return False
+
+        if not self.iotype:
+            raise ValidationError(
+                "Param `{}` cannot be turned to an initializer without a valid type! "
+                "Please set an input with a type to use the `to_init` field.".format(
+                    self.name
+                )
+            )
+
+        if self.param.connection:
+            return True
+
+        if self.iotype in {types.GIT, types.ARTIFACTS, types.DOCKERFILE}:
+            return True
+
+        raise ValidationError(
+            "Param `{}` with type `{}`, "
+            "cannot be turned to an init container automatically.".format(
+                self.name, self.iotype, self.param.ref
+            )
+        )
+
+    def to_init(self) -> Optional[V1Init]:
+        if not self.param.to_init:
+            return None
+        if self.iotype == types.GIT:
+            return V1Init.from_dict(
+                dict(git=self.param.value, connection=self.param.connection)
+            )
+        elif self.iotype == types.DOCKERFILE:
+            return V1Init.from_dict(
+                dict(dockerfile=self.param.value, connection=self.param.connection)
+            )
+        elif self.iotype == types.ARTIFACTS:
+            return V1Init.from_dict(
+                dict(artifacts=self.param.value, connection=self.param.connection)
+            )
+        elif self.param.connection:
+            return V1Init(connection=self.param.connection)
+        return None
+
     def validate_ref(
         self,
         context: Optional[Dict],
