@@ -79,7 +79,7 @@ class V1Dag(BaseConfig, polyaxon_sdk.V1Dag):
     Args:
         kind: str, should be equal `dag`
         operations: List[[V1Operation](/docs/core/specification/operation/)]
-        components: List[[V1Operation](/docs/core/specification/component/)], optional
+        components: List[[V1Component](/docs/core/specification/component/)], optional
         environment: [V1Environment](/docs/core/specification/environment/), optional
         connections: List[str], optional
         volumes: List[[Kubernetes Volume](https://kubernetes.io/docs/concepts/storage/volumes/)],
@@ -280,11 +280,11 @@ class V1Dag(BaseConfig, polyaxon_sdk.V1Dag):
     concurrency and other queue priority definitions.
 
     Operations can reference components using:
-        * [dagRef](/docs/core/specification/operation/#hub_ref)
+        * [dagRef](/docs/core/specification/operation/#dagRef)
             (reusable component defined inside the dag)
-        * [hubRef](/docs/core/specification/operation/#hub_ref)
-        * [pathRef](/docs/core/specification/operation/#path_ref)
-        * [urlRef](/docs/core/specification/operation/#url_ref)
+        * [hubRef](/docs/core/specification/operation/#hubRef)
+        * [pathRef](/docs/core/specification/operation/#pathRef)
+        * [urlRef](/docs/core/specification/operation/#urlRef)
         * [inline component](/docs/core/specification/operation/#component)
 
     ```yaml
@@ -468,11 +468,6 @@ class V1Dag(BaseConfig, polyaxon_sdk.V1Dag):
         self._components_by_names = {}  # ComponentName -> Component
         self._op_component_mapping = {}  # OpName -> ComponentName
         self._context = {}  # Ops output names -> types
-        # This is only usable from cli, the full op must be resolved before it can be submitted
-        self._path_context = None
-
-    def set_path_context(self, path_context):
-        self._path_context = path_context
 
     @property
     def dag(self):
@@ -505,7 +500,12 @@ class V1Dag(BaseConfig, polyaxon_sdk.V1Dag):
 
         for param in op.params:
             param_spec = op.params[param].get_spec(
-                name=param, iotype=None, is_flag=None, is_list=None
+                name=param,
+                iotype=None,
+                is_flag=None,
+                is_list=None,
+                is_context=None,
+                arg_format=None,
             )
             if param_spec.param.is_ops_ref:
                 upstream.add(param_spec.param.entity_ref)
@@ -557,9 +557,13 @@ class V1Dag(BaseConfig, polyaxon_sdk.V1Dag):
         return dags.sort_topologically(dag or self.dag, flatten=flatten)
 
     def process_components(self, inputs=None):
-        from polyaxon.polyaxonfile.check import collect_references
-
         inputs = inputs or []
+        self._context["dag.name"] = V1IO(
+            name="name", iotype=types.STR, value="", is_optional=True
+        )
+        self._context["dag.uuid"] = V1IO(
+            name="uuid", iotype=types.STR, value="", is_optional=True
+        )
         for _input in inputs:
             self._context["dag.inputs.{}".format(_input.name)] = _input
 
@@ -582,17 +586,7 @@ class V1Dag(BaseConfig, polyaxon_sdk.V1Dag):
 
         for op in self.operations:
             op_name = op.name
-            if op.has_url_reference or op.has_path_reference:
-                try:
-                    op = collect_references(op, self._path_context)
-                except Exception as e:
-                    raise PolyaxonSchemaError(
-                        "Pipeline op with name `{}` requires a component with ref `{}`, "
-                        "the reference could not be resolved. Error: {}".format(
-                            op_name, op.hub_ref or op.url_ref or op.path_ref, e
-                        )
-                    )
-            elif op.has_hub_reference:
+            if op.has_hub_reference:
                 continue
             if op.has_component_reference:
                 outputs = op.component.outputs
@@ -617,7 +611,7 @@ class V1Dag(BaseConfig, polyaxon_sdk.V1Dag):
                 inputs = self._components_by_names[component_ref_name].inputs
             else:
                 raise PolyaxonSchemaError(
-                    "Pipeline op has no template field `{}`".format(op_name)
+                    "Pipeline op has no definition field `{}`".format(op_name)
                 )
 
             if outputs:
@@ -662,16 +656,16 @@ class V1Dag(BaseConfig, polyaxon_sdk.V1Dag):
             if op.has_hub_reference:
                 continue
             elif op.has_component_reference:
-                component_ref = op.template.name
-                outputs = op.template.outputs
-                inputs = op.template.inputs
+                component_ref = op.definition.name
+                outputs = op.definition.outputs
+                inputs = op.definition.inputs
             elif op.has_dag_reference:
-                component_ref = op.template.name
+                component_ref = op.definition.name
                 outputs = self._components_by_names[component_ref].outputs
                 inputs = self._components_by_names[component_ref].inputs
             else:
                 raise PolyaxonSchemaError(
-                    "Pipeline op has no template field `{}`".format(op.name)
+                    "Pipeline op has no definition field `{}`".format(op.name)
                 )
             ops_params.validate_params(
                 params=op.params,
@@ -700,12 +694,12 @@ class V1Dag(BaseConfig, polyaxon_sdk.V1Dag):
                 "which is not defined on this pipeline, "
                 "make sure to run `process_components`".format(
                     op_name,
-                    op_spec.op.template.kind,
-                    op_spec.op.template.get_kind_value(),
+                    op_spec.op.definition.kind,
+                    op_spec.op.definition.get_kind_value(),
                 )
             )
         component_ref_name = self._op_component_mapping[op_name]
-        op_spec.op.set_template(self._components_by_names[component_ref_name])
+        op_spec.op.set_definition(self._components_by_names[component_ref_name])
 
     def get_op_spec_by_index(self, idx):
         from polyaxon.polyaxonfile import OperationSpecification
