@@ -16,9 +16,11 @@
 
 from typing import List, Optional
 
-from polyaxon.containers.containers import V1PolyaxonInitContainer
+from polyaxon.auxiliaries import V1PolyaxonInitContainer
+from polyaxon.connections.kinds import V1ConnectionKind
 from polyaxon.containers.contexts import CONTEXT_MOUNT_ARTIFACTS
 from polyaxon.containers.names import INIT_GIT_CONTAINER_PREFIX, generate_container_name
+from polyaxon.env_vars.keys import POLYAXON_KEYS_SSH_PATH
 from polyaxon.exceptions import PolypodException
 from polyaxon.k8s import k8s_schemas
 from polyaxon.polypod.common import constants
@@ -27,6 +29,7 @@ from polyaxon.polypod.common.env_vars import (
     get_connection_env_var,
     get_env_from_config_map,
     get_env_from_secret,
+    get_env_var,
     get_items_from_config_map,
     get_items_from_secret,
 )
@@ -42,20 +45,29 @@ from polyaxon.utils.list_utils import to_list
 
 
 def get_repo_context_args(
-    name: str, url: str, revision: str, mount_path: str, connection: str = None
+    name: str,
+    url: str,
+    revision: str,
+    mount_path: str,
+    connection: str = None,
+    flags: List[str] = None,
 ) -> List[str]:
     if not name:
         raise PolypodException("A repo name is required to create a repo context.")
     if not url:
         raise PolypodException("A repo url is required to create a repo context.")
 
-    args = ["--repo_path={}/{}".format(mount_path, name), "--url={}".format(url)]
+    args = ["--repo-path={}/{}".format(mount_path, name), "--url={}".format(url)]
 
     if revision:
         args.append("--revision={}".format(revision))
 
     if connection:
         args.append("--connection={}".format(connection))
+
+    flags = to_list(flags, check_none=True)
+    if flags:
+        args.append('--flags="{}"'.format(" ".join(flags)))
     return args
 
 
@@ -100,6 +112,9 @@ def get_git_init_container(
     env += to_list(
         get_connection_env_var(connection=connection, secret=secret), check_none=True
     )
+    # Add special handling to auto-inject ssh mount path
+    if connection.kind == V1ConnectionKind.SSH and secret.schema.mount_path:
+        env += [get_env_var(POLYAXON_KEYS_SSH_PATH, secret.schema.mount_path)]
     config_map = connection.get_config_map()
     if config_map:
         volume_mounts += to_list(
@@ -113,8 +128,10 @@ def get_git_init_container(
         )
     args = get_repo_context_args(
         name=connection.name,
-        url=connection.schema.url,
-        revision=connection.schema.revision,
+        # Handle the case of custom connection
+        url=getattr(connection.schema, "url", None),
+        revision=getattr(connection.schema, "revision", None),
+        flags=getattr(connection.schema, "flags", None),
         mount_path=mount_path,
         connection=connection.name if track else None,
     )
