@@ -13,8 +13,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import os
 
-from collections import Mapping, OrderedDict
+from collections import OrderedDict
+from collections.abc import Mapping
 from datetime import timezone
 
 import ujson
@@ -24,10 +26,11 @@ from marshmallow.utils import EXCLUDE
 
 from polyaxon import pkg
 from polyaxon.config_reader.spec import ConfigSpec
+from polyaxon.config_reader.utils import deep_update
 from polyaxon.exceptions import PolyaxonSchemaError
+from polyaxon.schemas.patch_strategy import V1PatchStrategy
 from polyaxon.schemas.utils import to_camel_case
 from polyaxon.utils.humanize import humanize_timesince
-from polyaxon.utils.list_utils import to_list
 from polyaxon.utils.tz_utils import get_timezone
 from polyaxon.utils.units import to_percentage, to_unit_memory
 
@@ -71,6 +74,13 @@ class BaseConfig:
     PERCENT_ATTRIBUTES = []
     ROUNDING = 2
     UNKNOWN_BEHAVIOUR = RAISE
+    WRITE_MODE = 0o777
+    FIELDS_MANUAL_PATCH = []
+    FIELDS_SAME_KIND_PATCH = []
+
+    @staticmethod
+    def _dump(obj_dict):
+        return ujson.dumps(obj_dict)
 
     def to_light_dict(
         self,
@@ -96,7 +106,7 @@ class BaseConfig:
             obj_dict.pop(attr, None)
 
         if dump:
-            return ujson.dumps(obj_dict)
+            return self._dump(obj_dict)
         return obj_dict
 
     def to_dict(
@@ -116,7 +126,7 @@ class BaseConfig:
             include_version=include_version,
         )
         if dump:
-            return ujson.dumps(obj)
+            return self._dump(obj)
         return obj
 
     def to_schema(self):
@@ -182,12 +192,132 @@ class BaseConfig:
         return cls.from_dict(values, unknown=unknown)
 
     @classmethod
-    def patch_obj(cls, config, values):
-        values = [config.to_dict()] + to_list(values)
-        return cls.read(values=values)
+    def init_file(cls, filepath: str, config=None):
+        if not os.path.exists(filepath):
+            cls.write(config or cls(), filepath=filepath)
+            os.chmod(filepath, cls.WRITE_MODE)
 
-    def patch(self, values):
-        return self.patch_obj(self, values)
+    def write(self, filepath: str):
+        with open(filepath, "w") as config_file:
+            config_file.write(self.to_dict(dump=True))
+
+    @staticmethod
+    def patch_normal_merge(current_value, value, strategy: V1PatchStrategy = None):
+        strategy = strategy or V1PatchStrategy.POST_MERGE
+
+        if isinstance(current_value, Mapping):
+            if strategy == V1PatchStrategy.POST_MERGE:
+                return deep_update(current_value, value)
+            elif strategy == V1PatchStrategy.PRE_MERGE:
+                return deep_update(value, current_value)
+        elif isinstance(current_value, list):
+            if strategy == V1PatchStrategy.POST_MERGE:
+                return current_value + [i for i in value if i not in current_value]
+            elif strategy == V1PatchStrategy.PRE_MERGE:
+                return value + [i for i in current_value if i not in value]
+        elif isinstance(current_value, BaseConfig):
+            return current_value.patch(value, strategy=strategy)
+        elif hasattr(current_value, "to_dict"):
+            if strategy == V1PatchStrategy.POST_MERGE:
+                return deep_update(current_value.to_dict(), value.to_dict())
+            elif strategy == V1PatchStrategy.PRE_MERGE:
+                return deep_update(value.to_dict(), current_value.to_dict())
+        else:
+            if strategy == V1PatchStrategy.POST_MERGE:
+                return value
+            elif strategy == V1PatchStrategy.PRE_MERGE:
+                return current_value
+
+    @classmethod
+    def patch_swagger_field(cls, config, values, strategy: V1PatchStrategy = None):
+        strategy = strategy or V1PatchStrategy.POST_MERGE
+
+        openapi_types = getattr(config, "openapi_types", {})
+        for key in openapi_types:
+            value = getattr(values, key, None)
+            if value is None:
+                continue
+
+            current_value = getattr(config, key, None)
+            if current_value is None:
+                setattr(
+                    config, key, value
+                )  # handles also V1PatchStrategy.ISNULL implicitly
+                continue
+
+            if strategy == V1PatchStrategy.ISNULL:
+                continue
+            if strategy == V1PatchStrategy.REPLACE:
+                setattr(config, key, value)
+                continue
+
+            setattr(config, key, cls.patch_normal_merge(current_value, value, strategy))
+
+    @classmethod
+    def patch_obj(cls, config, values, strategy: V1PatchStrategy = None):
+        strategy = strategy or V1PatchStrategy.POST_MERGE
+
+        for key in config.SCHEMA._declared_fields.keys():
+            if key in cls.FIELDS_MANUAL_PATCH:
+                continue
+
+            value = getattr(values, key, None)
+            if value is None:
+                continue
+
+            current_value = getattr(config, key, None)
+            if current_value is None:
+                setattr(
+                    config, key, value
+                )  # handles also V1PatchStrategy.ISNULL implicitly
+                continue
+
+            if (
+                isinstance(current_value, BaseConfig)
+                and key not in cls.FIELDS_SAME_KIND_PATCH
+            ):
+                current_value.patch(value, strategy=strategy)
+                continue
+
+            if not isinstance(current_value, BaseConfig) and hasattr(
+                current_value, "openapi_types"
+            ):
+                cls.patch_swagger_field(current_value, value, strategy)
+                continue
+
+            if strategy == V1PatchStrategy.ISNULL:
+                continue
+            if strategy == V1PatchStrategy.REPLACE:
+                setattr(config, key, value)
+                continue
+
+            # We only handle merge strategies
+            def normal_merge():
+                setattr(
+                    config, key, cls.patch_normal_merge(current_value, value, strategy)
+                )
+
+            def same_kind_merge():
+                # If the same kind resume merge patch using base logic
+                if current_value.kind == value.kind:
+                    normal_merge()
+                # Not same kind use post/pre replace
+                else:
+                    if strategy == V1PatchStrategy.POST_MERGE:
+                        setattr(config, key, value)
+                    elif strategy == V1PatchStrategy.PRE_MERGE:
+                        setattr(config, key, current_value)
+
+            if key in cls.FIELDS_SAME_KIND_PATCH:
+                same_kind_merge()
+            else:
+                normal_merge()
+
+        return config
+
+    def patch(self, values, strategy: V1PatchStrategy = None):
+        strategy = strategy or V1PatchStrategy.POST_MERGE
+        return self.patch_obj(self, values, strategy)
 
     @staticmethod
     def localize_date(dt):
@@ -198,10 +328,18 @@ class BaseConfig:
         return dt.astimezone(get_timezone())
 
     @classmethod
-    def to_jsonschema(cls):
+    def to_jsonschema(cls, dump: bool = True):
         from marshmallow_jsonschema import JSONSchema  # pylint:disable=import-error
 
-        return JSONSchema().dump(cls.SCHEMA())  # pylint:disable=not-callable
+        value = JSONSchema().dump(cls.SCHEMA())  # pylint:disable=not-callable
+        if dump:
+            return cls._dump(value)
+        return value
+
+    @classmethod
+    def write_jsonschema(cls, filepath: str):
+        with open(filepath, "w") as config_file:
+            config_file.write(cls.to_jsonschema(dump=True))
 
 
 class BaseOneOfSchema(Schema):
