@@ -39,6 +39,7 @@ class ConnectionTypeSchema(BaseCamelSchema):
         required=True, validate=validate.OneOf(V1ConnectionKind.allowable_values)
     )
     description = fields.Str(allow_none=True)
+    tags = fields.List(fields.Str(), allow_none=True)
     schema = fields.Nested(ConnectionSchema, allow_none=True)
     secret = fields.Nested(K8sResourceSchema, allow_none=True)
     config_map = fields.Nested(K8sResourceSchema, allow_none=True)
@@ -52,6 +53,7 @@ class ConnectionTypeSchema(BaseCamelSchema):
         schema = data.get("schema")
         kind = data.get("kind")
         if schema and kind:
+            schema["kind"] = "custom"
             if kind in V1ConnectionKind.BLOB_VALUES:
                 schema["kind"] = V1BucketConnection.IDENTIFIER
 
@@ -78,15 +80,15 @@ class V1ConnectionType(BaseConfig, polyaxon_sdk.V1ConnectionType):
     to automatically connect and load information.
 
     Using connections you can define the boilerplate required
-    to connect a volume or a blob storage once,
-    and end users, e.g. data scientist, can just reference the name of the connection to use it
+    to connect a volume, a blob storage once, secret definition for loading data from a data source.
+    Rnd users, e.g. data scientist, can just reference the name of the connection to use it
     without dealing with the configuration every time.
 
     Connections are not required to mount secrets or configurations,
     in fact users can also mount secrets and volumes the Kubernetes way,
     but this mean you are exposing the service to very few team members who have
-    the Kubernetes know-how,
-    in some advance use-cases, you will have to leverage the low level Kubernetes API,
+    the Kubernetes know-how, in some advance use-cases,
+    you will have to leverage the low level Kubernetes API,
     but for most interactions, using the connection specification is much simpler,
     similar to how easy it is to define service accounts or image pull secrets instead of
     defining all the volumes and mounting them to the containers manually.
@@ -94,19 +96,20 @@ class V1ConnectionType(BaseConfig, polyaxon_sdk.V1ConnectionType):
     For some distributions, Polyaxon will exposes:
         * Analytics about how often connections are used.
         * Jobs that requested those connections.
-        * Profiling and run time meta data to optimize access to those resources and connections.
+        * Profiling and runtime meta data to optimize access to those resources and connections.
         * Additional RBAC and ACL rules to control who can access the connections.
 
     Args:
          name: str
          description: str, optional
+         tags: List[str], optional
          kind: str, Union[`host_path`, `volume_claim`, `gcs`, `s3`, `wasb`, `registry`, `git`,
                           `aws`, `gcp`, `azure`, `mysql`, `postgres`, `oracle`, `vertica`,
                           `sqlite`, `mssql`, `redis`, `presto`, `mongo`, `cassandra`, `ftp`,
                           `grpc`, `hdfs`, `http`, `pig_cli`, `hive_cli`, `hive_metastore`,
                           `hive_server2`, `jdbc`, `jenkins`, `samba`, `snowflake`, `ssh`,
                           `cloudant`, `databricks`, `segment`, `slack`, `discord`, `mattermost`,
-                          `pager_duty`, `hipchat`, `webhook`, `custom`]
+                          `pagerduty`, `hipchat`, `webhook`, `custom`]
         schema: dict, optional
         secret: str, optional
         config_map: str, optional
@@ -124,6 +127,8 @@ class V1ConnectionType(BaseConfig, polyaxon_sdk.V1ConnectionType):
     >>>     name: "az-secret"
     >>> connections:
     >>>   - name: repo-test
+    >>>     description: "some description"
+    >>>     tags: ["tag1", "tag2"]
     >>>     kind: git
     >>>     schema:
     >>>       url: https://gitlab.com/org/test
@@ -156,17 +161,20 @@ class V1ConnectionType(BaseConfig, polyaxon_sdk.V1ConnectionType):
 
     ### description
 
-    A short description of the purpose of the connection for other users to learn
-    about purpose of this connection.
+    A short description about the purpose of the connection for other users.
 
     For example, "s3 bucket with radio images"
 
+    ### tags
+
+    Tags to categorize the connection in the connections catalog table.
+
     ### kind
 
-    the kind of the connection. Apart from the fact that the Polyaxon
+    the kind of the connection. Apart from the fact that Polyaxon
     has built-in handlers for several connections, user can build their own handlers,
     for example you can create a handler for pulling data from a database
-    ora data lake based on a specific kind.
+    or a data lake based on a specific kind.
 
     Polyaxon will show a small connection logo for some types in the
     dashboard and analytics about the connection usage.
@@ -178,18 +186,16 @@ class V1ConnectionType(BaseConfig, polyaxon_sdk.V1ConnectionType):
      `grpc`, `hdfs`, `http`, `pig_cli`, `hive_cli`, `hive_metastore`,
      `hive_server2`, `jdbc`, `jenkins`, `samba`, `snowflake`, `ssh`,
      `cloudant`, `databricks`, `segment`, `slack`, `discord`, `mattermost`,
-     `pager_duty`, `hipchat`, `webhook`, `custom`]
+     `pagerduty`, `hipchat`, `webhook`, `custom`]
 
     Polyaxon can also automatically handle these connection kinds:
     [`host_path`, `volume_claim`, `gcs`, `s3`, `wasb`, `registry`, `git`]
 
     ### schema
 
-     In order to leverage some built-in functionalities in Polyaxon,
-    e.g. automatic management of outputs,
-    initializers for cloning code from git repos,
-    loading data from S3/GCS/Azure/Volumes/Paths,
-    or pushing container images to a registry,
+    In order to leverage some built-in functionalities in Polyaxon,
+    e.g. automatic management of outputs, initializers for cloning code from git repos,
+    loading data from S3/GCS/Azure/Volumes/Paths, or pushing container images to a registry,
     the schema is how Polyaxon knows how to authenticate the containers that will handle that logic.
 
     If you opt-out of using those functionalities, you can leave this field empty or
@@ -201,12 +207,13 @@ class V1ConnectionType(BaseConfig, polyaxon_sdk.V1ConnectionType):
         * [docker registry connections](/docs/setup/connections/registry/)
 
     ### secret
+
     We assume that each connection will only need to access to at most one secret.
     If you are building a specific handler for a connection,
     this is where you will need to expose the necessary paths or environment variables needed
     to make the http/grpc connection.
 
-    In many cases you might not need to expose any secret, for instance for volumes and hot paths.
+    In many cases you might not need to expose any secret, for instance for volumes and host paths.
 
     The connection secret schema has 3 fields:
 
@@ -263,6 +270,7 @@ class V1ConnectionType(BaseConfig, polyaxon_sdk.V1ConnectionType):
         "name",
         "kind",
         "description",
+        "tags",
         "schema",
         "secret",
         "configMap",
