@@ -1,7 +1,23 @@
+#!/usr/bin/python
+#
+# Copyright 2018-2020 Polyaxon, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 # pylint:disable=inconsistent-return-statements
 
 
-class IgnoreRawDecorator(object):
+class IgnoreRawDecorator:
     """
     The `IgnoreRawDecorator` is a decorator to ignore raw/fixture data during signals handling.
 
@@ -24,7 +40,7 @@ class IgnoreRawDecorator(object):
         return self.f(*args, **kwargs)
 
 
-class IgnoreUpdatesDecorator(object):
+class IgnoreUpdatesDecorator:
     """
     The `IgnoreUpdatesDecorator` is a decorator to ignore signals for updates.
 
@@ -48,7 +64,7 @@ class IgnoreUpdatesDecorator(object):
         return self.f(*args, **kwargs)
 
 
-class IgnoreUpdatesPreDecorator(object):
+class IgnoreUpdatesPreDecorator:
     """
     The `IgnoreUpdatesPreDecorator` is a decorator to ignore signals for updates.
 
@@ -72,7 +88,7 @@ class IgnoreUpdatesPreDecorator(object):
         return self.f(*args, **kwargs)
 
 
-class CheckSpecificationDecorator(object):
+class CheckSpecificationDecorator:
     """
     The `CheckSpecificationDecorator` is a decorator to check if an instance has a specification.
 
