@@ -15,16 +15,15 @@
 # limitations under the License.
 
 import os
+import pytest
 import tempfile
 import uuid
 
-import pytest
-
 from mock import patch
-from tests.utils import BaseTestCase
 
 from polyaxon.client.impersonate import create_context_auth, impersonate
 from polyaxon.schemas.api.authentication import AccessTokenConfig
+from tests.utils import BaseTestCase
 
 
 @pytest.mark.client_mark
@@ -32,7 +31,7 @@ class TestImpersonate(BaseTestCase):
     def test_create_context_auth(self):
         token = uuid.uuid4().hex
         context_mount = tempfile.mkdtemp()
-        context_mount_auth = "{}/.polyaxonauth".format(context_mount)
+        context_mount_auth = "{}/.auth".format(context_mount)
 
         # Login without updating the token and without persistence
         if os.path.exists(context_mount_auth):
