@@ -13,14 +13,13 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from tests.utils import BaseTestCase
-
 from polyaxon.lifecycle import LifeCycle, V1Statuses
+from tests.utils import BaseTestCase
 
 
 class TestStatusesTransition(BaseTestCase):
     def test_values(self):
-        assert len(V1Statuses.allowable_values) == 17
+        assert len(V1Statuses.allowable_values) == 20
 
     def test_warning_statuses(self):
         assert LifeCycle.WARNING_VALUES == {
@@ -37,6 +36,8 @@ class TestStatusesTransition(BaseTestCase):
 
     def test_running_statuses(self):
         assert LifeCycle.RUNNING_VALUES == {
+            V1Statuses.INITIALIZING,
+            V1Statuses.PROCESSING,
             V1Statuses.STARTING,
             V1Statuses.RUNNING,
         }
@@ -66,6 +67,14 @@ class TestStatusesTransition(BaseTestCase):
             else:
                 assert LifeCycle.is_unschedulable(status) is False
 
+    def test_is_compilable(self):
+        assert LifeCycle.is_unschedulable(None) is False
+        for status in V1Statuses.allowable_values:
+            if status in LifeCycle.COMPILABLE_VALUES:
+                assert LifeCycle.is_compilable(status) is True
+            else:
+                assert LifeCycle.is_compilable(status) is False
+
     def test_is_warning(self):
         assert LifeCycle.is_warning(None) is False
         for status in V1Statuses.allowable_values:
@@ -114,6 +123,7 @@ class TestStatusesTransition(BaseTestCase):
                 or LifeCycle.is_unschedulable(status)
                 or LifeCycle.is_warning(status=status)
                 or LifeCycle.is_unknown(status=status)
+                or status == V1Statuses.SCHEDULED
             )
             if cond:
                 assert LifeCycle.is_k8s_stoppable(status) is True
