@@ -14,11 +14,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import datetime
-
 import pytest
 
 from dateutil.tz import tzutc
-from tests.utils import BaseTestCase
 
 from polyaxon.exceptions import PolyaxonSchemaError
 from polyaxon.parser import parser
@@ -33,7 +31,7 @@ from polyaxon.schemas.types import (
     V1UriType,
     V1WasbType,
 )
-from polyaxon.schemas.types.image import V1ImageType
+from tests.utils import BaseTestCase
 
 
 @pytest.mark.parser_mark
@@ -259,6 +257,9 @@ class TestParser(BaseTestCase):
         )
         self.assertEqual(value, [1.23, 13.3, 4.4, 555.0, 66.0])
 
+        value = parser.get_float(key="float_from_int", value=123)
+        self.assertEqual(value, 123.0)
+
         with self.assertRaises(PolyaxonSchemaError):
             parser.get_float(key="float_error_key_1", value=None)
 
@@ -271,9 +272,6 @@ class TestParser(BaseTestCase):
         with self.assertRaises(PolyaxonSchemaError):
             parser.get_float(key="float_error_key_3", value="foo")
 
-        with self.assertRaises(PolyaxonSchemaError):
-            parser.get_float(key="float_error_key_4", value=123)
-
         with self.assertRaises(PolyaxonSchemaError):
             parser.get_float(
                 key="float_list_key_1", value=[1.23, 13.3, "4.4", "555", 66.0]
@@ -1185,9 +1183,9 @@ class TestParser(BaseTestCase):
 
         value = parser.get_git_init(
             key="dict_key_1",
-            value={"revision": "foo", "connection": "foo", "init": True},
+            value={"revision": "foo"},
         )
-        self.assertEqual(value, V1GitType(revision="foo", connection="foo", init=True))
+        self.assertEqual(value, V1GitType(revision="foo"))
 
         value = parser.get_git_init(
             key="dict_key_1", value={"url": "https://github.com", "revision": "foo"}
@@ -1220,6 +1218,22 @@ class TestParser(BaseTestCase):
             ],
         )
 
+        with self.assertRaises(PolyaxonSchemaError):
+            parser.get_git_init(
+                key="dict_error_key_1",
+                value=dict(revision="foo", connection="foo", init=True),
+            )
+
+        with self.assertRaises(PolyaxonSchemaError):
+            parser.get_git_init(
+                key="dict_error_key_1", value=dict(revision="foo", init=True)
+            )
+
+        with self.assertRaises(PolyaxonSchemaError):
+            parser.get_git_init(
+                key="dict_error_key_1", value=dict(revision="foo", connection="foo")
+            )
+
         with self.assertRaises(PolyaxonSchemaError):
             parser.get_git_init(key="dict_error_key_1", value="foo")
 
@@ -1281,38 +1295,48 @@ class TestParser(BaseTestCase):
         )
 
     def test_get_image_init(self):
+        value = parser.get_image_init(key="dict_key_1", value="foo")
+        self.assertEqual(value, "foo")
+
         value = parser.get_image_init(key="dict_key_1", value={"name": "foo"})
-        self.assertEqual(value, V1ImageType(name="foo"))
+        self.assertEqual(value, "foo")
+
+        value = parser.get_image_init(key="dict_key_1", value="foo:bar")
+        self.assertEqual(value, "foo:bar")
 
         value = parser.get_image_init(
             key="dict_key_1", value={"name": "foo:bar", "connection": "foo"}
         )
-        self.assertEqual(value, V1ImageType(name="foo:bar", connection="foo"))
+        self.assertEqual(value, "foo:bar")
+
+        value = parser.get_image_init(
+            key="dict_key_1", value="https://registry.com/foo:bar"
+        )
+        self.assertEqual(value, "https://registry.com/foo:bar")
 
         value = parser.get_image_init(
             key="dict_key_1", value='{"name": "https://registry.com/foo:bar"}'
         )
-        self.assertEqual(value, V1ImageType(name="https://registry.com/foo:bar"))
+        self.assertEqual(value, "https://registry.com/foo:bar")
 
         value = parser.get_image_init(
             key="dict_list_key_1",
             value=[
                 {"name": "https://registry.com/foo:bar"},
                 {"name": "test", "connection": "registry"},
+                "foo:bar",
             ],
             is_list=True,
         )
         self.assertEqual(
             value,
             [
-                V1ImageType(name="https://registry.com/foo:bar"),
-                V1ImageType(name="test", connection="registry"),
+                "https://registry.com/foo:bar",
+                "test",
+                "foo:bar",
             ],
         )
 
-        with self.assertRaises(PolyaxonSchemaError):
-            parser.get_image_init(key="dict_error_key_1", value="foo")
-
         with self.assertRaises(PolyaxonSchemaError):
             parser.get_image_init(key="dict_error_key_2", value=1)
 
@@ -1372,38 +1396,46 @@ class TestParser(BaseTestCase):
 
     def test_get_artifacts_init(self):
         value = parser.get_artifacts_init(
-            key="dict_key_1", value={"files": ["foo", "bar"], "connection": "foo"}
+            key="dict_key_1", value={"files": ["foo", "bar"]}
         )
-        self.assertEqual(value, V1ArtifactsType(connection="foo", files=["foo", "bar"]))
+        self.assertEqual(value, V1ArtifactsType(files=["foo", "bar"]))
 
         value = parser.get_artifacts_init(
-            key="dict_key_1", value={"connection": "foo", "init": True}
+            key="dict_key_1", value='{"dirs": ["foo", "bar"]}'
         )
-        self.assertEqual(value, V1ArtifactsType(connection="foo", init=True))
-
-        value = parser.get_artifacts_init(
-            key="dict_key_1", value='{"connection": "foo", "dirs": ["foo", "bar"]}'
-        )
-        self.assertEqual(value, V1ArtifactsType(connection="foo", dirs=["foo", "bar"]))
+        self.assertEqual(value, V1ArtifactsType(dirs=["foo", "bar"]))
 
         value = parser.get_artifacts_init(
             key="dict_list_key_1",
             value=[
-                {"connection": "foo", "dirs": ["foo", "bar"], "files": ["foo", "bar"]},
-                {"connection": "foo", "init": True},
+                {"dirs": ["foo", "bar"], "files": ["foo", "bar"]},
+                {"files": ["foo", "bar"]},
             ],
             is_list=True,
         )
         self.assertEqual(
             value,
             [
-                V1ArtifactsType(
-                    connection="foo", dirs=["foo", "bar"], files=["foo", "bar"]
-                ),
-                V1ArtifactsType(connection="foo", init=True),
+                V1ArtifactsType(dirs=["foo", "bar"], files=["foo", "bar"]),
+                V1ArtifactsType(files=["foo", "bar"]),
             ],
         )
 
+        with self.assertRaises(PolyaxonSchemaError):
+            parser.get_artifacts_init(
+                key="dict_key_1", value={"connection": "foo", "init": True}
+            )
+
+        with self.assertRaises(PolyaxonSchemaError):
+            parser.get_artifacts_init(
+                key="dict_key_1", value={"init": True, "dirs": ["foo", "bar"]}
+            )
+
+        with self.assertRaises(PolyaxonSchemaError):
+            parser.get_artifacts_init(
+                key="dict_key_1", value={"connection": "foo", "files": ["foo", "bar"]}
+            )
+
         with self.assertRaises(PolyaxonSchemaError):
             parser.get_artifacts_init(
                 key="dict_error_key_1", value={"paths": ["foo", "bar"]}
