@@ -15,15 +15,14 @@
 # limitations under the License.
 
 import os
-
 import pytest
 
 from mock import patch
-from tests.utils import BaseTestCase
 
 from polyaxon.exceptions import PolyaxonSchemaError
 from polyaxon.k8s.k8s_schemas import V1Container
 from polyaxon.polyaxonfile import check_polyaxonfile
+from polyaxon.polyaxonfile.check import collect_dag_components
 from polyaxon.polyaxonfile.specs import (
     CompiledOperationSpecification,
     OperationSpecification,
@@ -36,6 +35,7 @@ from polyaxon.polyflow.early_stopping import (
 from polyaxon.polyflow.matrix import V1GridSearch, V1Hyperband, V1RandomSearch
 from polyaxon.polyflow.matrix.params import V1HpChoice, V1HpLinSpace
 from polyaxon.polyflow.run import V1Dag
+from tests.utils import BaseTestCase
 
 
 @pytest.mark.polyaxonfile_mark
@@ -48,7 +48,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
             ]
         )
         with self.assertRaises(PolyaxonSchemaError):
-            CompiledOperationSpecification.apply_context(run_config)
+            CompiledOperationSpecification.apply_operation_contexts(run_config)
 
     def test_pipeline_with_no_components_raises(self):
         run_config = V1CompiledOperation.read(
@@ -60,7 +60,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
             ]
         )
         with self.assertRaises(PolyaxonSchemaError):
-            CompiledOperationSpecification.apply_context(run_config)
+            CompiledOperationSpecification.apply_operation_contexts(run_config)
 
     def test_pipeline_ops_not_corresponding_to_components(self):
         run_config = V1CompiledOperation.read(
@@ -72,7 +72,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
             ]
         )
         with self.assertRaises(PolyaxonSchemaError):
-            CompiledOperationSpecification.apply_context(run_config)
+            CompiledOperationSpecification.apply_operation_contexts(run_config)
 
     def test_cyclic_pipeline_raises(self):
         run_config = V1CompiledOperation.read(
@@ -84,7 +84,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
         assert run_config.is_dag_run is True
         assert run_config.has_pipeline is True
         with self.assertRaises(PolyaxonSchemaError):
-            CompiledOperationSpecification.apply_context(run_config)
+            CompiledOperationSpecification.apply_operation_contexts(run_config)
 
     def test_cron_pipeline(self):
         plx_file = check_polyaxonfile(
@@ -97,7 +97,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
         # Get compiled_operation data
         run_config = OperationSpecification.compile_operation(plx_file)
 
-        run_config = CompiledOperationSpecification.apply_context(run_config)
+        run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
         assert run_config.run is not None
         assert len(run_config.run.operations) == 1
         assert run_config.run.operations[0].name == "cron-task"
@@ -119,7 +119,10 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
                 inputs=[V1IO(name="str-input", iotype="str")],
                 run=V1Job(container=V1Container(name="test")),
             ).to_dict()
-            compiled_op = CompiledOperationSpecification.apply_context(run_config)
+            collect_dag_components(run_config.run)
+        compiled_op = CompiledOperationSpecification.apply_operation_contexts(
+            run_config
+        )
         assert compiled_op.run is not None
         assert len(compiled_op.run.operations) == 2
         assert compiled_op.run.operations[0].name == "ref-path-op"
@@ -136,7 +139,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
         # Get compiled_operation data
         run_config = OperationSpecification.compile_operation(plx_file)
 
-        run_config = CompiledOperationSpecification.apply_context(run_config)
+        run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
         assert run_config.run is not None
         assert len(run_config.run.operations) == 1
         assert run_config.run.operations[0].name == "recurrent-task"
@@ -157,7 +160,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
             ]
         )
 
-        run_config = CompiledOperationSpecification.apply_context(run_config)
+        run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
         assert run_config.run is not None
         assert len(run_config.run.operations) == 4
         assert run_config.run.operations[0].name == "job1"
@@ -186,7 +189,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
             ]
         )
 
-        run_config = CompiledOperationSpecification.apply_context(run_config)
+        run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
         assert len(run_config.run.operations) == 4
         assert run_config.run.operations[0].name == "job1"
         assert run_config.run.operations[0].dependencies is None
@@ -214,7 +217,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
             ]
         )
 
-        run_config = CompiledOperationSpecification.apply_context(run_config)
+        run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
         assert len(run_config.run.operations) == 5
         assert run_config.run.operations[0].name == "job1"
         assert run_config.run.operations[1].name == "experiment1"
@@ -245,7 +248,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
             ]
         )
 
-        run_config = CompiledOperationSpecification.apply_context(run_config)
+        run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
         assert len(run_config.run.operations) == 2
         assert run_config.run.operations[0].name == "build"
         assert run_config.run.operations[1].name == "run"
@@ -284,8 +287,8 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
         }
         run_config = OperationSpecification.compile_operation(job_config)
         run_config.apply_params({"image": {"value": "foo"}, "lr": {"value": 0.001}})
-        run_config = CompiledOperationSpecification.apply_context(run_config)
-        run_config = CompiledOperationSpecification.apply_run_contexts(run_config)
+        run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
+        run_config = CompiledOperationSpecification.apply_runtime_contexts(run_config)
         assert run_config.termination.to_dict() == {"maxRetries": 2}
         assert run_config.run.to_dict() == {
             "kind": V1RunKind.JOB,
@@ -313,7 +316,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
             ]
         )
 
-        run_config = CompiledOperationSpecification.apply_context(run_config)
+        run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
         assert run_config.run is not None
         assert run_config.is_dag_run is True
         assert run_config.has_pipeline is True
@@ -351,7 +354,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
                 {"kind": "compiled_operation"},
             ]
         )
-        run_config = CompiledOperationSpecification.apply_context(run_config)
+        run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
         assert run_config.version == 1.1
         assert run_config.is_dag_run is True
         assert run_config.has_pipeline is True
@@ -402,7 +405,7 @@ class TestPolyaxonfileWithPipelines(BaseTestCase):
             ]
         )
 
-        run_config = CompiledOperationSpecification.apply_context(run_config)
+        run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
         assert run_config.version == 1.1
         assert run_config.is_dag_run is True
         assert run_config.has_pipeline is True
