@@ -16,9 +16,8 @@
 
 import pytest
 
-from tests.utils import BaseTestCase, assert_equal_dict
-
 from polyaxon.polyflow.environment import V1Environment
+from tests.utils import BaseTestCase, assert_equal_dict
 
 
 @pytest.mark.environment_mark
@@ -84,3 +83,9 @@ class TestEnvironmentsConfigs(BaseTestCase):
         config_dict["restartPolicy"] = "Never"
         config = V1Environment.from_dict(config_dict)
         assert_equal_dict(config_dict, config.to_dict())
+
+        # Add host namespaces
+        config_dict["hostNetwork"] = True
+        config_dict["hostPID"] = True
+        config = V1Environment.from_dict(config_dict)
+        assert_equal_dict(config_dict, config.to_dict())
