@@ -13,8 +13,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from tests.utils import BaseTestCase
-
 from polyaxon import settings
 from polyaxon.auxiliaries import V1PolyaxonInitContainer, V1PolyaxonSidecarContainer
 from polyaxon.connections.kinds import V1ConnectionKind
@@ -43,11 +41,12 @@ from polyaxon.schemas.types import (
     V1K8sResourceType,
 )
 from polyaxon.services.headers import PolyaxonServices
+from tests.utils import BaseTestCase
 
 
 class DummyConverter(PlatformJobConverter):
     SPEC_KIND = "dumy"
-    K8S_LABELS_NAME = "dummy-name"
+    K8S_ANNOTATIONS_KIND = "dummy-name"
     MAIN_CONTAINER_ID = "dummy"
 
 
@@ -182,6 +181,7 @@ class TestJobConverter(BaseTestCase):
                 connection=store,
                 artifacts=None,
                 env=self.converter.get_init_service_env_vars(),
+                is_default_artifacts_store=True,
             ),
         ]
 
@@ -228,6 +228,7 @@ class TestJobConverter(BaseTestCase):
                 connection=store,
                 artifacts=V1ArtifactsType(files=["/foo", "/bar"]),
                 env=self.converter.get_init_service_env_vars(),
+                is_default_artifacts_store=True,
             ),
             get_store_container(
                 polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
@@ -288,7 +289,11 @@ class TestJobConverter(BaseTestCase):
 
     def test_get_init_containers_with_git_without_connection(self):
         git1 = V1GitConnection(revision="test", url="https://test.com")
-        git2 = V1GitConnection(revision="test", url="https://test.com")
+        git2 = V1GitConnection(
+            revision="test",
+            url="https://test.com",
+            flags=["--falg1", "--flag2=test", "k=v"],
+        )
         containers = self.converter.get_init_containers(
             contexts=None,
             artifacts_store=None,
@@ -312,7 +317,7 @@ class TestJobConverter(BaseTestCase):
             get_git_init_container(
                 container=k8s_schemas.V1Container(name="test"),
                 connection=V1ConnectionType(
-                    name=git2.get_name(), kind=V1ConnectionKind.GIT, schema=git1
+                    name=git2.get_name(), kind=V1ConnectionKind.GIT, schema=git2
                 ),
                 mount_path="/test",
                 polyaxon_init=V1PolyaxonInitContainer(image="foo/foo"),
