@@ -16,14 +16,12 @@
 
 import pytest
 
-from tests.utils import BaseTestCase
-
-from polyaxon.containers.containers import V1PolyaxonInitContainer, get_init_resources
+from polyaxon.auxiliaries import V1PolyaxonInitContainer, get_init_resources
 from polyaxon.containers.contexts import (
     CONTEXT_MOUNT_ARTIFACTS,
     CONTEXT_MOUNT_RUN_OUTPUTS_FORMAT,
 )
-from polyaxon.containers.names import INIT_DOCKERFILE_CONTAINER
+from polyaxon.containers.names import INIT_DOCKERFILE_CONTAINER_PREFIX
 from polyaxon.polyflow import V1Plugins
 from polyaxon.polypod.common import constants
 from polyaxon.polypod.common.env_vars import get_run_instance_env_var
@@ -35,6 +33,7 @@ from polyaxon.polypod.common.volumes import get_volume_name
 from polyaxon.polypod.init.dockerfile import get_dockerfile_init_container
 from polyaxon.polypod.specs.contexts import PluginsContextsSpec
 from polyaxon.schemas.types.dockerfile import V1DockerfileType
+from tests.utils import BaseTestCase
 
 
 @pytest.mark.polypod_mark
@@ -47,8 +46,9 @@ class TestInitDockerfile(BaseTestCase):
             env=None,
             contexts=PluginsContextsSpec.from_config(V1Plugins(auth=True)),
             run_path="test",
+            run_instance="foo.bar.runs.uuid",
         )
-        assert INIT_DOCKERFILE_CONTAINER.format("") in container.name
+        assert INIT_DOCKERFILE_CONTAINER_PREFIX in container.name
         assert container.image == "foo"
         assert container.image_pull_policy is None
         assert container.command == ["polyaxon", "docker", "generate"]
@@ -56,8 +56,11 @@ class TestInitDockerfile(BaseTestCase):
             "--build-context={}".format(dockerfile_args.to_dict(dump=True)),
             "--destination={}".format(CONTEXT_MOUNT_ARTIFACTS),
             "--copy-path={}".format(CONTEXT_MOUNT_RUN_OUTPUTS_FORMAT.format("test")),
+            "--track",
+        ]
+        assert container.env == [
+            get_run_instance_env_var(run_instance="foo.bar.runs.uuid")
         ]
-        assert container.env == [get_run_instance_env_var()]
         assert container.resources == get_init_resources()
         assert container.volume_mounts == [
             get_connections_context_mount(
@@ -84,8 +87,9 @@ class TestInitDockerfile(BaseTestCase):
             mount_path="/somepath",
             contexts=PluginsContextsSpec.from_config(V1Plugins(auth=True)),
             run_path="test",
+            run_instance="foo.bar.runs.uuid",
         )
-        assert INIT_DOCKERFILE_CONTAINER.format("") in container.name
+        assert INIT_DOCKERFILE_CONTAINER_PREFIX in container.name
         assert container.image == "init/init"
         assert container.image_pull_policy == "IfNotPresent"
         assert container.command == ["polyaxon", "docker", "generate"]
@@ -93,8 +97,11 @@ class TestInitDockerfile(BaseTestCase):
             "--build-context={}".format(dockerfile_args.to_dict(dump=True)),
             "--destination=/somepath",
             "--copy-path={}".format(CONTEXT_MOUNT_RUN_OUTPUTS_FORMAT.format("test")),
+            "--track",
+        ]
+        assert container.env == [
+            get_run_instance_env_var(run_instance="foo.bar.runs.uuid")
         ]
-        assert container.env == [get_run_instance_env_var()]
         assert container.resources == get_init_resources()
         assert container.volume_mounts == [
             get_connections_context_mount(
