@@ -14,11 +14,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import tempfile
-
 import pytest
-
-from tests.utils import BaseTestCase
+import tempfile
 
 from polyaxon import settings
 from polyaxon.auxiliaries import (
@@ -28,12 +25,13 @@ from polyaxon.auxiliaries import (
 from polyaxon.connections.kinds import V1ConnectionKind
 from polyaxon.connections.schemas import V1BucketConnection, V1K8sResourceSchema
 from polyaxon.exceptions import PolyaxonCompilerError
-from polyaxon.managers.agent import AgentManager
+from polyaxon.managers.agent import AgentConfigManager
 from polyaxon.polyaxonfile.specs import kinds
 from polyaxon.polyflow import V1CompiledOperation, V1RunKind
 from polyaxon.polypod.compiler.resolver import BaseResolver
 from polyaxon.schemas.cli.agent_config import AgentConfig
 from polyaxon.schemas.types import V1ConnectionType, V1K8sResourceType
+from tests.utils import BaseTestCase
 
 
 @pytest.mark.polypod_mark
@@ -117,7 +115,7 @@ class TestResolver(BaseTestCase):
 
     def test_resolve_connections_with_invalid_config(self):
         fpath = tempfile.mkdtemp()
-        AgentManager.CONFIG_PATH = fpath
+        AgentConfigManager.CONFIG_PATH = fpath
         secret1 = V1K8sResourceType(
             name="secret1",
             schema=V1K8sResourceSchema(name="secret1"),
