@@ -18,24 +18,23 @@ import os
 import tarfile
 import tempfile
 
-from tests.utils import BaseTestCase
-
 from polyaxon.utils.path_utils import (
     append_basename,
-    create_project_tarfile,
+    create_tarfile_from_path,
     get_files_by_paths,
     get_files_in_path_context,
     get_path,
 )
+from tests.utils import BaseTestCase
 
 
 class TestFiles(BaseTestCase):
     def test_get_path(self):
         assert get_path("/foo", "bar") == "/foo/bar"
 
-    def test_create_project_tarfile(self):
+    def test_create_tarfile_from_path(self):
         files = ["tests/test_utils/__init__.py"]
-        with create_project_tarfile(files, "project_name") as tar_file_name:
+        with create_tarfile_from_path(files, "project_name") as tar_file_name:
             assert os.path.exists(tar_file_name)
             with tarfile.open(tar_file_name) as tf:
                 members = tf.getmembers()
@@ -69,6 +68,26 @@ class TestFiles(BaseTestCase):
         with open(fpath3, "w") as f:
             f.write("data3")
 
+        dirname3 = tempfile.mkdtemp(prefix=dirname + "/")
+        fpath4 = dirname3 + "/test4.txt"
+        with open(fpath4, "w") as f:
+            f.write("data1")
+
+        fpath5 = dirname3 + "/test5.txt"
+        with open(fpath5, "w") as f:
+            f.write("data2")
+
+        dirname4 = tempfile.mkdtemp(prefix=dirname3 + "/")
+        fpath6 = dirname4 + "/test6.txt"
+        with open(fpath6, "w") as f:
+            f.write("data3")
+
         with get_files_in_path_context(dirname) as files:
+            assert len(files) == 6
+            assert set(files) == {fpath1, fpath2, fpath3, fpath4, fpath5, fpath6}
+
+        with get_files_in_path_context(
+            dirname, exclude=[dirname3.split("/")[-1]]
+        ) as files:
             assert len(files) == 3
             assert set(files) == {fpath1, fpath2, fpath3}
